"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createWorkingKey = void 0;
const crypto = require("crypto");
const util_1 = require("./util");
const crypto_1 = require("./crypto");
const handle_pwd_1 = require("./handle_pwd");
/**
 * 保存 Working_key密文 以及 初始化向量
 * @param rootKey 根秘钥
 * @param pwd 用户密码
 * @param userPath 用户路径
 */
function createKeyIv(rootKey, pwd, userPath) {
    // 生成 256 位 Working_key 明文
    const workingData = crypto.randomBytes(32).toString('hex');
    // 生成及保存 初始化向量
    const iv = crypto.randomBytes(8).toString('hex');
    util_1.writeFileData({ ASE_iv: iv }, userPath);
    // 得到并保存 Working_key 密文
    crypto_1.encrypt(workingData, rootKey, userPath, (result) => {
        util_1.writeFileData({ Working_key: result }, userPath);
    });
    // 加密 password
    handle_pwd_1.cryptoPwd(pwd, workingData, userPath);
}
/**
 * 处理 working_key 以及 password
 * @param rootKey 根秘钥
 * @param workingKey working_key 密文
 * @param pwd 用户密码
 * @param userPath 用户路径
 */
function transformWorkingKey(rootKey, workingKey, pwd, userPath) {
    // 1. 将 working_key 密文 转换为 working_key 明文
    crypto_1.decrypt(workingKey, rootKey, userPath, (result) => {
        // 2. 将 password 明文 转换为 password密文
        handle_pwd_1.cryptoPwd(pwd, result, userPath);
    });
}
/**
 * 当前文件入口函数
 * @param rootKey 根秘钥
 * @param pwd 用户密码
 * @param userPath 用户路径
 */
function createWorkingKey(rootKey, pwd, userPath) {
    const json = util_1.readFileData(userPath);
    // 初始化向量 或 工作秘钥 不存在
    if (!json.ASE_iv || !json.Working_key) {
        createKeyIv(rootKey, pwd, userPath);
    }
    else {
        transformWorkingKey(rootKey, json.Working_key, pwd, userPath);
    }
}
exports.createWorkingKey = createWorkingKey;
//# sourceMappingURL=create_working_key.js.map