"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.decrypt = exports.encrypt = void 0;
// ============ 加密/解密数据模块 ===========
const crypto = require("crypto");
const util_1 = require("./util");
// ------------------ 加密数据 -------------------
const algorithm = 'aes-256-gcm'; // algorithm 是算法的意思
const keyLength = 32;
/**
 * 获取 盐值 和 初始化向量
 * @param userPath 用户路径
 */
function getData(userPath) {
    const json = util_1.readFileData(userPath);
    const salt = json.Salt_key; // 盐值
    const iv = json.ASE_iv; // 初始化向量
    return {
        salt,
        iv
    };
}
/**
 * @param data 要加密的数据，必须是utf8格式的字符串
 * @param password 用于生产密钥的密码
 * @param userPath 用户路径
 * @param callback 处理结果集的回调函数
 */
function encrypt(data, password, userPath, callback) {
    const { salt, iv } = getData(userPath);
    crypto.scrypt(password, salt, keyLength, (err, derivedKey) => {
        if (err) {
            throw err;
        }
        else {
            const cipher = crypto.createCipheriv(algorithm, derivedKey, iv); // 创建 cipher 实例
            // 加密数据
            let cipherText = cipher.update(data, 'utf8', 'hex');
            cipherText += cipher.final('hex');
            cipherText += (password + salt + iv);
            callback(cipherText);
        }
    });
}
exports.encrypt = encrypt;
/**
 * 解密通过 encrypt(); 加密的数据
 * @param cipherText 通过 encrypt() 加密的数据
 * @param password 用于生产密钥的密码
 * @param userPath 用户路径
 * @param callback 处理结果集的回调函数
 */
function decrypt(cipherText, password, userPath, callback) {
    const { salt, iv } = getData(userPath);
    const len = cipherText.length - password.length - salt.length - iv.length;
    const data = cipherText.slice(0, len); // 获取密文
    const key = crypto.scryptSync(password, salt, keyLength);
    if (key) {
        const decipher = crypto.createDecipheriv(algorithm, key, iv);
        const txt = decipher.update(data, 'hex', 'utf8');
        callback(txt);
    }
}
exports.decrypt = decrypt;
//# sourceMappingURL=crypto.js.map