"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PLUGIN_PATH = exports.delUser = exports.getPwd = exports.savaData = void 0;
const path = require('path');
const create_root_key_1 = require("./create_root_key");
const util_1 = require("./util");
const handle_err_scene_1 = require("./handle_err_scene");
const crypto_1 = require("./crypto");
const PLUGIN_PATH = path.join(__dirname, '../../');
exports.PLUGIN_PATH = PLUGIN_PATH;
const MESSAGE = {
    infochinese: '加密文件已损坏，请重新输入密码',
    info: 'The encrypted file is damaged, please re-enter the password'
};
/**
 * 生成 本地文件 保存 相关数据
 * @param pwd 用户密码
 * @param username 用户名
 * @param serverMark 服务器标识 ip:port
 */
function savaData(username, pwd, serverMark) {
    if (typeof username !== 'string' || typeof pwd !== 'string') {
        return {
            infochinese: '用户名或密码类型不对，请传入字符串'
        };
    }
    if (!util_1.regPwd(pwd)) {
        return {
            infochinese: '必须包含大写字母、小写字母、数字以及特殊字符（`~!@#$%^&*()-_=+\\|[{}];:\'",<.>/?）中两种及以上类型的组合，长度为8~32个字符，不能含空格。',
            info: 'It must contain 8 to 32 characters and at least two types of the following characters: \
uppercase letters, lowercase letters, digits, and special characters (`~!@#$%^&*()-_=+\\|[{}];:\'",<.>/?).\
Spaces are not allowed.'
        };
    }
    // 生成对应的 用户目录  serverMark/username
    const userPath = `${PLUGIN_PATH}/${util_1.replaceMark(serverMark)}@${username}`;
    create_root_key_1.handleRootKey(pwd, userPath);
}
exports.savaData = savaData;
/**
 * 根据保存的 password 密文 得到 相应的明文
 * @param username 用户名
 * @param serverMark 服务器地址
 * @param cb 回调函数 获取明文密码
 */
function getPwd(username, serverMark, cb) {
    // 生成对应的 用户目录  serverMark@username
    const userPath = `${PLUGIN_PATH}/${util_1.replaceMark(serverMark)}@${username}`;
    const result = handle_err_scene_1.handleErrScene(userPath);
    if (!result) {
        cb(MESSAGE);
    }
    const json = util_1.readFileData(userPath);
    if (!json) {
        return false;
    }
    // 1. 获取 root_key 以及 working_key(工作密文)
    const rootKey = create_root_key_1.createRootKey(userPath);
    const workingKey = json.Working_key;
    // 2. 解密 working_key明文
    crypto_1.decrypt(workingKey, rootKey, userPath, (workKey) => {
        if (workKey.length !== 64) {
            util_1.delFolder(userPath);
            cb(MESSAGE);
        }
        // 3. 获取 password 密文
        const pwdKey = json.Password_key;
        // 4. 解密 password 明文
        crypto_1.decrypt(pwdKey, workKey, userPath, (pwd) => {
            cb(pwd);
        });
    });
}
exports.getPwd = getPwd;
/**
 * 删除指定的用户 所保存的相关信息
 * @param username 用户名
 * @param serverMark 服务器地址
 */
function delUser(username, serverMark) {
    const userPath = `${PLUGIN_PATH}/${util_1.replaceMark(serverMark)}@${username}`;
    const result = handle_err_scene_1.handleErrScene(userPath);
    if (!result) {
        return false;
    }
    util_1.delFolder(userPath);
}
exports.delUser = delUser;
//# sourceMappingURL=index.js.map