"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.replaceMark = exports.delFolder = exports.sertFilePermission = exports.writeFileData = exports.readFileData = exports.regPwd = exports.xor = void 0;
const fs = require("fs");
/**
 * 16进制 异或方法
 * @returns 返回异或后的 16进制
 */
function xor(...items) {
    if (items.length < 2) {
        throw new Error('argument error');
    }
    let minLen = items[0].length;
    items.forEach((element) => {
        minLen = element.length < minLen ? element.length : minLen;
    });
    const hexArr = [];
    for (let i = 0; i < minLen; i++) {
        const xorRes = items.reduce((a, c) => {
            const aChart = a;
            const cChart = c[i];
            const aDec = parseInt(aChart, 16);
            const cDec = parseInt(cChart, 16);
            // 以下场景需使用位运算，因此禁用tslint
            // tslint:disable-next-line:no-bitwise
            const xorVal = aDec ^ cDec;
            return xorVal.toString(16);
        }, '0');
        hexArr.push(xorRes);
    }
    return hexArr.join('');
}
exports.xor = xor;
/**
 * 正则校验密码是否满足规则
 * @param pwd 密码
 */
function regPwd(pwd) {
    // 正则表达式不能换行，因此禁用tslint长度检测
    const reg = new RegExp(
    // tslint:disable-next-line:max-line-length
    /^(?![A-Z]+$)(?![a-z]+$)(?!\d+$)(?![`~!@#$%^&*()\-_=+\|\[\{\}\];:'\\",<.>/? ]+$)[A-Za-z\d`~!@#$%^&*()\-_=+\|\[\{\}\];:'\\",<.>/? ]{8,32}$/);
    return reg.test(pwd);
}
exports.regPwd = regPwd;
/**
 * 将传过来的对象写入 data中
 * @param obj 要写入的数据
 * @param userPath 用户路径
 */
function writeFileData(obj, userPath) {
    const content = fs.readFileSync(`${userPath}/.e/.p`, 'utf-8');
    const newObj = Object.assign(JSON.parse(content), obj);
    fs.writeFileSync(`${userPath}/.e/.p`, JSON.stringify(newObj));
}
exports.writeFileData = writeFileData;
/**
 * 读取保存的数据
 * @param userPath 用户路径
 */
function readFileData(userPath) {
    try {
        const content = fs.readFileSync(`${userPath}/.e/.p`, 'utf-8');
        return JSON.parse(content);
    }
    catch (error) {
        return false;
    }
}
exports.readFileData = readFileData;
/**
 * 设置文件权限 文件夹：700 文件：600
 * @param path 要设置的具体路径
 * @param isFolder 是否为 文件夹
 */
function sertFilePermission(path, isFolder) {
    isFolder ? fs.chmodSync(path, 0o700) : fs.chmodSync(path, 0o600);
}
exports.sertFilePermission = sertFilePermission;
/**
 * 递归删除对应用户 文件夹
 * @param path 路径
 */
function delFolder(path) {
    try {
        const fileList = fs.readdirSync(path);
        fileList.forEach((file) => {
            const curPath = `${path}/${file}`;
            // 如果是文件夹
            if (fs.statSync(curPath).isDirectory()) {
                delFolder(curPath);
            }
            else { // 删除文件
                fs.unlinkSync(curPath);
            }
        });
        fs.rmdirSync(path);
    }
    catch (error) {
        throw new Error('当前用户目录不存在');
    }
}
exports.delFolder = delFolder;
/**
 * 文件夹名称无法使用: 替换为@
 * @param serverMark 服务器标识
 */
function replaceMark(serverMark) {
    return serverMark.replace(':', '@');
}
exports.replaceMark = replaceMark;
//# sourceMappingURL=util.js.map