"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.uploadFileWithReport = exports.uploadFileWithProgress = exports.downloadResource = exports.downloadResourceWithProgress = exports.createWorkDir = exports.trans2Dir = void 0;
const ssh2tools_1 = require("../ssh2tool/ssh2tools");
const vscode_api_1 = require("../vscode_api");
const vscode_api_2 = require("../vscode_api/vscode_api");
const global_constants_1 = require("../consts/global_constants");
const web_request_1 = require("../utils/web_request");
/**
 * 给文件夹路径添加上/
 * @param dirPath
 */
function trans2Dir(dirPath) {
    return (dirPath.length && (dirPath[dirPath.length - 1] !== '/'))
        ? dirPath + '/'
        : dirPath;
}
exports.trans2Dir = trans2Dir;
/**
 * 添加远端工作目录（没有才添加）
 * @param conn 连接实例
 * @param remoteDir 远端文件夹路径
 */
function createWorkDir(conn, remoteDir) {
    return __awaiter(this, void 0, void 0, function* () {
        // 判断工作目录是否存在，存在先删除，不存在则创建
        const sftp = new ssh2tools_1.Sftp(conn);
        const workDirExists = yield sftp.packExists(remoteDir);
        if (workDirExists) {
            yield conn.rmFileRemote(remoteDir);
        }
        try {
            yield conn.mkDirRemote(remoteDir);
        }
        catch (e) {
            throw e;
        }
    });
}
exports.createWorkDir = createWorkDir;
function downloadResourceWithProgress(url, localPath) {
    return __awaiter(this, void 0, void 0, function* () {
        vscode_api_1.default.setProgressOption({
            title: `${vscode_api_2.I18n.common_tip.download_just_wait}`,
            cancellable: true,
        });
        // 调起进度条下载文件到本地
        try {
            yield vscode_api_1.default.showProgress((p, t) => __awaiter(this, void 0, void 0, function* () {
                try {
                    // 联网下载
                    yield downloadResource(url, localPath, p, t);
                }
                catch (e) {
                    throw e;
                }
            }));
        }
        catch (e) {
            throw e;
        }
    });
}
exports.downloadResourceWithProgress = downloadResourceWithProgress;
function downloadResource(url, localPath, p, t) {
    return __awaiter(this, void 0, void 0, function* () {
        const cancel = {
            isCancel: false,
            onCancel: t.onCancellationRequested
        };
        // 当下载速度达不到0.9MB/s时就转换为KB/s显示
        const downloadSpeed = (speed) => (speed / global_constants_1.MB) < 0.9
            ? `${(speed / global_constants_1.KB).toFixed(2)}KB/s`
            : `${(speed / global_constants_1.MB).toFixed(2)}MB/s`;
        let lastPercent = 0;
        // 给进度条组件传递进度信息
        const progress = (loaded, total, speed) => {
            const percent = Number(((loaded / total) * 100).toFixed(2));
            const increment = percent - lastPercent;
            lastPercent = percent;
            p.report({
                message: `${percent}%(speed: ${downloadSpeed(speed)})`,
                increment
            });
        };
        for (let i = 0; i < global_constants_1.MAX_LOAD_NUM; i++) {
            try {
                yield web_request_1.downloadWebFile({
                    url,
                    localPath,
                    cancel,
                    progress
                });
                break;
            }
            catch (e) {
                // 处理联网下载失败的各种情况
                if (cancel.isCancel) {
                    vscode_api_1.default.writeLog('debug', '取消下载');
                    throw e;
                }
                else if (e.message === 'net error') {
                    // 未连接网络时直接失败
                    vscode_api_1.default.writeLog('debug', '网络错误');
                    throw new Error(vscode_api_2.I18n.common_tip.net_error);
                }
                else if (e.message === 'not expected response') {
                    // 被拦截时自动重新下载，三次以后报错
                    vscode_api_1.default.writeLog('debug', '下载失败:' + e.message);
                    if (i === global_constants_1.MAX_LOAD_NUM - 1) {
                        throw new Error(vscode_api_2.I18n.common_tip.net_error);
                    }
                }
                else {
                    vscode_api_1.default.writeLog('debug', '下载失败:' + e.message);
                    throw e;
                }
            }
        }
    });
}
exports.downloadResource = downloadResource;
function uploadFileWithProgress(conn, localPath, remotePath) {
    return __awaiter(this, void 0, void 0, function* () {
        vscode_api_1.default.setProgressOption({
            title: `${vscode_api_2.I18n.common_tip.upload_just_wait}`,
            cancellable: true,
        });
        // 调起进度条上传文件到服务器
        try {
            yield vscode_api_1.default.showProgress((p, t) => __awaiter(this, void 0, void 0, function* () {
                try {
                    // 上传到服务器
                    yield uploadFileWithReport(conn, localPath, remotePath, p, t);
                }
                catch (e) {
                    throw e;
                }
            }));
        }
        catch (e) {
            throw e;
        }
    });
}
exports.uploadFileWithProgress = uploadFileWithProgress;
function uploadFileWithReport(conn, localPath, remotePath, p, t) {
    return __awaiter(this, void 0, void 0, function* () {
        const sftp = new ssh2tools_1.Sftp(conn);
        try {
            yield sftp.pureUploadFile(localPath, remotePath, p, t, {
                mode: 0o544
            });
        }
        catch (e) {
            throw e;
        }
    });
}
exports.uploadFileWithReport = uploadFileWithReport;
//# sourceMappingURL=util.js.map