"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const log4js_1 = require("log4js");
const index_1 = require("../vscode_api/index");
const path = require("path");
let logger4j;
let userLogger;
// 日志对象
const logger = {
    noOutput: (message, isInnerMsg = false) => { },
    debug: (message, isInnerMsg = false) => { },
    info: (message, isInnerMsg = false) => { },
    warn: (message, isInnerMsg = false) => { },
    error: (message, isInnerMsg = false) => { },
    logOpt: (message) => { },
    init: () => { },
    innerDescPref: '==========',
};
logger.logOpt = (message) => {
    userLogger.info(message);
};
logger.noOutput = (message, isInnerMsg = false) => {
    if (isInnerMsg) {
        message = logger.innerDescPref + message;
    }
    logger4j.info(message);
};
logger.error = (message, isInnerMsg = false) => {
    if (isInnerMsg) {
        message = logger.innerDescPref + message;
    }
    index_1.default.writeOutput('[error] ' + message, 'error');
    logger4j.error(message);
};
logger.warn = (message, isInnerMsg = false) => {
    if (isInnerMsg) {
        message = ' ' + logger.innerDescPref + message;
    }
    else {
        message = ' ' + message;
    }
    index_1.default.writeOutput('[warn] ' + message, 'warn');
    logger4j.warn(message);
};
logger.info = (message, isInnerMsg = false) => {
    if (isInnerMsg) {
        message = ' ' + logger.innerDescPref + message;
    }
    else {
        message = ' ' + message;
    }
    index_1.default.writeOutput('[info] ' + message, 'info');
    logger4j.info(message);
};
logger.debug = (message, isInnerMsg = false) => {
    if (isInnerMsg) {
        message = logger.innerDescPref + message;
    }
    index_1.default.writeOutput('[debug] ' + message, 'debug');
    logger4j.debug(message);
};
logger.init = () => {
    const maxSize = 20 * 1024 * 1024; // 20MB
    const logDir = path.join(index_1.default.extensionPath, 'log');
    const runDir = path.join(logDir, 'running_log');
    const optDir = path.join(logDir, 'operation_log');
    const filename1 = path.join(runDir, 'running.log');
    const filename2 = path.join(optDir, 'operation.log');
    try {
        log4js_1.configure({
            appenders: {
                running: {
                    type: 'file',
                    filename: filename1,
                    maxLogSize: maxSize,
                    backups: 2,
                    keepFileExt: true,
                    mode: 0o600
                },
                operation: {
                    type: 'file',
                    filename: filename2,
                    maxLogSize: maxSize,
                    backups: 2,
                    keepFileExt: true,
                    mode: 0o600
                }
            },
            categories: {
                default: {
                    appenders: ['running'],
                    level: 'debug'
                },
                operation: {
                    appenders: ['operation'],
                    level: 'debug'
                }
            }
        });
        logger4j = log4js_1.getLogger('running');
        userLogger = log4js_1.getLogger('operation');
    }
    catch (e) {
        console.log('日志初始化失败, 原因可能是：', e);
    }
};
exports.default = logger;
//# sourceMappingURL=log_manager.js.map