"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.registerEvent = exports.immediateConnect = void 0;
const fs = require("fs");
const path = require("path");
const vscode = require("vscode");
const vscode_api_1 = require("../vscode_api");
const ssh2tool_1 = require("../ssh2tool");
const tree_provider_1 = require("../tree_provider");
const global_constants_1 = require("../consts/global_constants");
const server_estimate_1 = require("../server_estimate");
const server_manage_1 = require("../server_manage");
const estimate_config_1 = require("../server_estimate/estimate.config");
const vscode_api_2 = require("../vscode_api/vscode_api");
const webview_provider_1 = require("../webview_provider");
const request_1 = require("./request");
const ssh2tools_1 = require("../ssh2tool/ssh2tools");
const create_root_key_1 = require("../crypto/create_root_key");
const crypto_1 = require("../crypto");
const util_1 = require("../crypto/util");
const deploy_easy_1 = require("../deploy_easy");
const global_constants_2 = require("../consts/global_constants");
const file_util_1 = require("../utils/file_util");
const base_util_1 = require("../utils/base_util");
const util_2 = require("../server_estimate/util");
const Subscribe_1 = require("../utils/Subscribe");
const HandleWebviewEvents_1 = require("./HandleWebviewEvents");
let conn;
function beforeEstimate(callback) {
    return new Promise((resolve, reject) => {
        callback(resolve, reject);
    });
}
function x2openEulerExists(resolve, reject) {
    server_estimate_1.ServerEstimate
        .x2openEulerExists(conn)
        .then((version) => {
        version ? resolve(version) : reject(vscode_api_2.I18n.common_deploy_easy.no_tool);
    })
        .catch(() => {
        reject(vscode_api_2.I18n.common_deploy_easy.no_tool);
    });
}
/**
 * 连接成功后
 * @param panel 保持连接的panel
 * @param data 可能需要的数据
 */
function connected(data, pwd, panel) {
    return __awaiter(this, void 0, void 0, function* () {
        const wp = new webview_provider_1.WebviewProvider();
        let page;
        if (panel) {
            page = panel;
        }
        else {
            try {
                page = yield wp.newTab('deploy/selection');
                wp.closeViewByID(view => view.id !== page.id && !view.stored.deploy);
            }
            catch (e) {
                throw e;
            }
        }
        const username = data.msg.username;
        const serverMark = `${data.msg.host}:${data.msg.port}`;
        data.msg.serverMark = serverMark;
        // 由于当前页面连接了服务器因此需要更新页面的serverMark信息
        webview_provider_1.WebviewProvider.defPanelStored(page, serverMark);
        vscode_api_1.default.writeLog('info', '连接成功:' + data.msg.host);
        // 判断是配置服务器还是部署
        if (data.operate === 'configure') {
            if (data.action && data.action === 'modifyServer') {
                server_manage_1.serverManage.modifyServer(data.msg, data.backupMsg);
                crypto_1.delUser(data.backupMsg.username, data.backupMsg.serverMark);
            }
            else {
                server_manage_1.serverManage.addServer(data.msg);
            }
            if (data.msg.remember) {
                let userPath = `${crypto_1.PLUGIN_PATH}/${util_1.replaceMark(serverMark)}@${username}`;
                create_root_key_1.handleRootKey(pwd, userPath);
            }
            else {
                crypto_1.delUser(username, serverMark);
            }
            if (data.action) {
                wp.closeViewByID(view => view.id !== page.id && !view.stored.deploy);
            }
            const disposable = vscode_api_1.default.registerTreeProvider('x2openEuler', tree_provider_1.default.createTree());
            tree_provider_1.default.setTreeDispose(disposable);
            try {
                yield new server_estimate_1.SoftwareEstimate(conn).historyReport.getReports(conn.getServerInfo());
                yield new server_estimate_1.HardwareEstimate(conn).historyReport.getReports(conn.getServerInfo());
                yield new server_estimate_1.DeployEstimate(conn).historyReport.getReports(conn.getServerInfo());
            }
            catch (e) {
                throw e;
            }
            tree_provider_1.default.instance.refresh();
            vscode_api_1.default.showMsg(vscode_api_2.I18n.common_tip.connection_succeeded); // '服务器配置成功'
            vscode_api_1.default.userLog('登录' + data.msg.host);
            let serverPages = wp.getPanelsByTitle(global_constants_1.PANEL_TITLE['deploy/server']);
            serverPages.forEach(item => {
                item.postMsg({
                    command: 'update-server',
                    data: {
                        active: server_manage_1.serverManage.active,
                        serverArray: server_manage_1.serverManage.serverArray
                    }
                });
            });
        }
        else if (data.operate === 'deploy') {
            // 远端工作目录如果存在就认为其他人在部署
            const sftp = new ssh2tools_1.Sftp(page.stored.conn);
            const isDirExist = yield sftp.packExists(global_constants_2.TMP_DIR);
            if (isDirExist) {
                return request_1.createResponse(page, 'connect', false, { message: 'server conflict' });
            }
        }
        request_1.createResponse(page, 'connect', true);
    });
}
/**
 * 开始连接
 * @param data  服务器数据
 * @param panel 保持连接的panel
 */
function connect(data, panel) {
    const serverInfo = data && data.msg;
    let serverPwd = data.msg.password;
    const serverMark = `${serverInfo.host}:${serverInfo.port}`;
    if (data.havePwd) {
        crypto_1.getPwd(data.msg.username, serverMark, (pwd) => {
            if (typeof (pwd) === 'string') {
                serverInfo.password = pwd;
                serverPwd = pwd;
            }
        });
    }
    if (!serverInfo)
        return;
    conn = new ssh2tool_1.default.SSH2Client(serverMark);
    conn
        .setServerConfig({
        readyTimeout: 2 * global_constants_1.MINUTE,
        server: serverInfo,
        authorization: {
            onAuthFail: () => {
                vscode_api_1.default
                    .errMsg(vscode_api_2.I18n.common_server_error.auth_error)
                    .userLog(vscode_api_2.I18n.common_server_error.auth_error);
            },
            onConnError: () => {
                vscode_api_1.default
                    .errMsg(vscode_api_2.I18n.common_server_error.conn_error)
                    .userLog(vscode_api_2.I18n.common_server_error.conn_error);
            },
            onConnTimeout: () => {
                vscode_api_1.default
                    .errMsg(vscode_api_2.I18n.common_server_error.timeout)
                    .userLog(vscode_api_2.I18n.common_server_error.timeout);
            }
        }
    })
        .connect2Server({
        onReady: () => {
            conn.getRootUsers()
                .then((rootUsers) => {
                if (!rootUsers.includes(conn.getServerInfo().username)) {
                    util_2.getBaseCMD(conn)
                        .then(() => connected(data, serverPwd, panel))
                        .catch((err) => {
                        if (err instanceof Error && err.message.search(/not available/) !== -1) {
                            vscode_api_1.default.catchError(new Error(vscode_api_2.I18n.common_server_error.nologin));
                        }
                        else {
                            vscode_api_1.default.catchError(new Error(vscode_api_2.I18n.common_server_error.notinstall));
                        }
                        request_1.createResponse(panel, 'connect', false, err);
                    });
                }
                else {
                    connected(data, serverPwd, panel);
                }
            });
        },
        onError: (err) => {
            request_1.createResponse(panel, 'connect', false, err);
        }
    });
}
function immediateConnect(data) {
    return __awaiter(this, void 0, void 0, function* () {
        const wp = new webview_provider_1.WebviewProvider();
        let pwd;
        try {
            crypto_1.getPwd(data.info.username, data.info.serverMark, (msg) => {
                pwd = msg;
            });
            if (typeof (pwd) === 'string') {
                connect({ msg: Object.assign(Object.assign({}, data.info), { password: pwd, remember: true }), operate: 'configure' });
            }
            else {
                vscode_api_1.default.errMsg(vscode_api_2.I18n.common_server_manage.no_password);
                let panel = yield wp.newTab();
                data.info.password = '';
                server_manage_1.serverManage.sendServer(panel, 'edit', data);
            }
        }
        catch (e) {
            throw e;
        }
    });
}
exports.immediateConnect = immediateConnect;
function registerEvent(panel, options) {
    const wp = new webview_provider_1.WebviewProvider();
    const events = HandleWebviewEvents_1.default();
    Object.keys(events).forEach((et) => {
        panel.receive(et, events[et]);
    });
    panel.receive('page-error', () => {
        panel.view.dispose();
        vscode_api_1.default.errMsg(vscode_api_2.I18n.common_server_error.page_data_error);
        vscode_api_1.default.writeLog('error', '报告数据异常');
    });
    panel.receive('page-quit', () => {
        panel.view.dispose();
    });
    panel.receive('page-prepared', () => {
        options.pagePrepared();
        Subscribe_1.default.emit('page-prepared');
    });
    // 提示消息
    panel.receive('show-msg', (data) => {
        vscode_api_1.default.showMsg(data.msg);
    });
    // 错误消息
    panel.receive('err-msg', (data) => {
        vscode_api_1.default.errMsg(data.msg);
        vscode_api_1.default.writeLog('error', '报错：' + data.info);
    });
    // 改变标题
    panel.receive('change-title', (data) => {
        wp.updateWebview({
            title: data.msg
        }, panel);
    });
    // 切换panel的html
    panel.receive('change-html', (data) => {
        wp.updateWebview({
            html: data.msg
        }, panel);
    });
    // 提示空文件夹
    panel.receive('empty-dir', () => {
        vscode_api_1.default.errMsg(vscode_api_2.I18n.common_file_error.empty_dir);
    });
    // 记录vue运行错误
    panel.receive('vue-error', (data) => {
        vscode_api_1.default.writeLog('error', '页面错误，原因：' + data.msg);
        vscode_api_1.default.writeLog('error', '页面错误，信息：' + data.info);
    });
    // 展示文件下载框
    panel.receive('show-saveDialog', (fileName) => __awaiter(this, void 0, void 0, function* () {
        const uri = yield vscode_api_1.default.showSaveDialog({
            defaultUri: vscode.Uri.file(fileName)
        });
        if (uri) {
            // uri.path ---> '/绝对路径'
            panel.postMsg({
                command: 'show-saveDialog__success',
                data: uri.path
            });
        }
    }));
    // 文件上传方法封装
    function uploadProgress(isDir, type, dir, overwrite, uri) {
        // 对于部署上传页面，用户使用本地上传时禁止用户点击下一步进入联网流程
        panel.postMsg({
            command: 'upload-start'
        });
        server_estimate_1.ServerEstimate.uploadProgress({
            conn: panel.stored.conn,
            isDir,
            settings: {
                cancellable: true
            },
            type,
            dir,
            overwrite,
            uri,
        })
            .then((file) => {
            if (file.hasOwnProperty('settings')) {
                delete file.conn;
                request_1.createResponse(panel, 'show-openDialog', false, file);
            }
            else {
                request_1.createResponse(panel, 'show-openDialog', true, file);
            }
        })
            .catch((e) => {
            let reason = '';
            if (e instanceof Error) {
                reason = e.message;
            }
            else {
                reason = vscode_api_2.I18n.common_tip.cancel_upload;
            }
            vscode_api_1.default.userLog(`上传失败，原因：${reason}`);
            request_1.createResponse(panel, 'show-openDialog', false, reason);
        })
            .finally(() => {
            // 无论上传成功还是失败都结束掉上传状态
            panel.postMsg({
                command: 'upload-finished'
            });
        });
    }
    // 展示文件上传框
    panel.receive('show-openDialog', (options) => __awaiter(this, void 0, void 0, function* () {
        const isFiles = options && options.isFiles;
        const isDir = options && options.isDir;
        const dir = options.deployDir ? global_constants_2.TMP_DIR : global_constants_2.WORK_DIR;
        if (options.overwrite === false) {
            let uri = yield vscode_api_1.default.showOpenDialog({
                canSelectFiles: isFiles || false,
                canSelectFolders: isDir || false,
                canSelectMany: true,
                openLabel: vscode_api_2.I18n.common_tip.upload_button
            });
            if (!uri) {
                return;
            }
            if (!isFiles) {
                uri = uri[0];
            }
            if (!Array.isArray(uri)) {
                beforeEstimate((resolve, reject) => {
                    if (conn.getServerInfo().username === 'root')
                        return resolve('');
                    x2openEulerExists(resolve, reject);
                }).then(() => {
                    uploadProgress(options.isDir, options.type, dir, false, uri);
                }).catch((reason) => {
                    vscode_api_1.default.errMsg(reason);
                    vscode_api_1.default.writeLog('error', reason);
                });
            }
        }
        else {
            // 覆盖标识为true
            uploadProgress(options.isDir, options.type, dir, true, options.lastUrl);
        }
    }));
    // 检查磁盘空间是否充足
    panel.receive('check-disk-space', () => __awaiter(this, void 0, void 0, function* () {
        try {
            let size = yield conn.checkInfo(global_constants_1.CHECK_DISK_SIZE);
            let gigabyteNum = base_util_1.getPartString(size, 'G');
            let terabyteNum = base_util_1.getPartString(size, 'T');
            if (gigabyteNum !== -1) {
                if (Number(gigabyteNum) <= global_constants_1.MIN_DISK_SPACE) {
                    throw new Error(vscode_api_2.I18n.common_deploy_easy.not_enough_space);
                }
            }
            else {
                if (terabyteNum === -1) {
                    throw new Error(vscode_api_2.I18n.common_deploy_easy.not_enough_space);
                }
            }
            request_1.createResponse(panel, 'check-disk-space', true);
        }
        catch (e) {
            if (e.message === 'no_connect')
                return;
            vscode_api_1.default.errMsg(e.message);
        }
    }));
    // 命令执行
    panel.receive('execute-cmd', (cmd) => __awaiter(this, void 0, void 0, function* () {
        yield vscode_api_1.default.executeCMD(cmd);
    }));
    // 打开外部链接
    panel.receive('open-url', (data) => {
        vscode_api_1.default.userLog('打开链接:' + data.url);
        vscode.commands.executeCommand('vscode.open', vscode.Uri.parse(data.url));
    });
    // 数据写入文件
    panel.receive('save-file', (data) => __awaiter(this, void 0, void 0, function* () {
        const { filePath, content } = data;
        file_util_1.saveFile(filePath, content);
        request_1.createResponse(panel, 'save-file', true);
    }));
    // 检测文件路径是否存在
    panel.receive('exist-file', (data) => __awaiter(this, void 0, void 0, function* () {
        const { filePath } = data;
        const absPath = path.join(vscode_api_1.default.extensionPath, filePath);
        let res = yield file_util_1.fileExistAsync(absPath);
        request_1.createResponse(panel, 'exist-file', true, res);
    }));
    // -----------------业务---------------------
    // 获取协议文件内容
    panel.receive('load-confirm-file', (data) => {
        const { filePath } = data;
        const content = file_util_1.loadFile(filePath);
        request_1.createResponse(panel, 'load-confirm-file', true, content);
    });
    // 获取已安装软件包
    panel.receive('get-installedpackages', () => __awaiter(this, void 0, void 0, function* () {
        let resStr = '';
        yield conn.exeCMDRemote('rpm -qa', {
            onData: (data) => {
                resStr += data;
            }
        });
        const res = resStr.split('\n');
        res.pop();
        request_1.createResponse(panel, 'get-installedpackages', true, res);
    }));
    // 获取密码文件内容
    panel.receive('load-pwd-file', (data) => {
        const { filePath } = data;
        const content = file_util_1.loadFile(filePath);
        request_1.createResponse(panel, 'load-pwd-file', true, content);
    });
    // 一键部署，检测是否部署
    panel.receive('check-deploy-easy', () => __awaiter(this, void 0, void 0, function* () {
        const deployEasy = new deploy_easy_1.default({
            conn: panel.stored.conn,
            panel
        });
        panel.stored.deploy = deployEasy;
        try {
            const res = yield deployEasy.toolExists();
            request_1.createResponse(panel, 'check-deploy-easy', true, res);
        }
        catch (e) {
            vscode_api_1.default.catchError(e);
        }
    }));
    // 部署前准备
    panel.receive('before-deploy-easy', () => {
        panel.stored.deploy.beforeDeploy();
    });
    // 部署后
    panel.receive('after-deploy-easy', () => {
        panel.stored.deploy.afterDeploy();
    });
    // 一键部署，部署工具
    panel.receive('deploy-easy', (fileName) => {
        const hasUploadFile = Boolean(fileName);
        panel.stored.deploy.gotoDeploy(hasUploadFile)
            .then((res) => {
            request_1.createResponse(panel, 'deploy-easy', true, res);
        })
            .catch((e) => {
            vscode_api_1.default.errMsg(e.message);
            request_1.createResponse(panel, 'deploy-easy', false);
        });
    });
    // 一键部署保存服务器信息
    panel.receive('deploy-easy-server', () => {
        const res = panel.stored.deploy.getServerData();
        panel.stored.deploy = null;
        request_1.createResponse(panel, 'deploy-easy-server', true, res);
    });
    // 接收页面传过来的密码
    panel.receive('save-x2-pwd', (pwd) => {
        if (pwd) {
            panel.stored.deploy.savePwd(pwd);
            request_1.createResponse(panel, 'save-x2-pwd', true);
        }
    });
    // 连接服务器
    panel.receive('connect', (data) => {
        connect(data, panel);
    });
    // 软件评估
    panel.receive('software-estimate', (form) => {
        beforeEstimate((resolve, reject) => {
            x2openEulerExists(resolve, reject);
        }).then(() => {
            vscode_api_1.default.userLog('开始软件评估');
            new server_estimate_1.SoftwareEstimate(conn).runEstimate(form, panel);
        }).catch((reason) => {
            vscode_api_1.default.errMsg(reason);
            vscode_api_1.default.writeLog('error', reason);
            request_1.createResponse(panel, 'software-estimate', false);
        });
    });
    // 配置评估
    panel.receive('config-estimate', (form) => {
        beforeEstimate((resolve, reject) => {
            x2openEulerExists(resolve, reject);
        }).then(() => {
            vscode_api_1.default.userLog('开始配置评估');
            new server_estimate_1.DeployEstimate(conn).runEstimate(form, panel);
        }).catch((reason) => {
            vscode_api_1.default.errMsg(reason);
            vscode_api_1.default.writeLog('error', reason);
            request_1.createResponse(panel, 'config-estimate', false);
        });
    });
    // 硬件评估
    panel.receive('hardware-estimate', (form) => {
        beforeEstimate((resolve, reject) => {
            x2openEulerExists(resolve, reject);
        }).then(() => {
            vscode_api_1.default.userLog('开始硬件评估');
            new server_estimate_1.HardwareEstimate(conn).runEstimate(form, panel);
        }).catch((reason) => {
            vscode_api_1.default.errMsg(reason);
            vscode_api_1.default.writeLog('error', reason);
            request_1.createResponse(panel, 'hardware-estimate', false);
        });
    });
    // 取消评估
    panel.receive('cancel-estimate', (data) => __awaiter(this, void 0, void 0, function* () {
        vscode_api_1.default.writeLog('info', '准备取消评估');
        panel.view.dispose();
        conn.exeCMDRemote(global_constants_1.HALT_EXECS, {
            onClose: (sign) => {
                if (sign === 0) {
                    vscode_api_1.default.writeLog('info', '取消评估成功');
                    vscode_api_1.default.userLog('取消评估成功');
                }
            }
        });
    }));
    // 发送历史报告
    panel.receive('get-history', (data) => __awaiter(this, void 0, void 0, function* () {
        vscode_api_1.default.writeLog('info', '准备获取本地历史报告');
        let list;
        switch (data) {
            case 'software':
                list = new server_estimate_1.SoftwareEstimate(conn).historyReport.reportList;
                break;
            case 'config':
                list = new server_estimate_1.DeployEstimate(conn).historyReport.reportList;
                break;
            case 'hardware':
                list = new server_estimate_1.HardwareEstimate(conn).historyReport.reportList;
                break;
            default:
                vscode_api_1.default.writeLog('error', '获取报告错误');
                break;
        }
        vscode_api_1.default.writeLog('info', '获取本地历史报告成功');
        request_1.createResponse(panel, 'get-history', true, {
            msg: list,
            Introduction: estimate_config_1.server
        });
    }));
    // 删除历史报告
    panel.receive('delete-report', (data) => __awaiter(this, void 0, void 0, function* () {
        const arr = ['software', 'config', 'hardware', 'installed'];
        // 删除的是评估软件还是配置收集和评估还是硬件评估
        let deleteWare = arr.filter((item) => data.deletePath.indexOf(`\\${item}\\`) > -1 || data.deletePath.indexOf(`/${item}/`) > -1)[0];
        if (deleteWare == 'installed') {
            deleteWare = 'software';
        }
        try {
            switch (deleteWare) {
                case 'software':
                    yield new server_estimate_1.SoftwareEstimate(conn).historyReport.removeHistoryReport(data);
                    break;
                case 'config':
                    yield new server_estimate_1.DeployEstimate(conn).historyReport.removeHistoryReport(data);
                    break;
                case 'hardware':
                    yield new server_estimate_1.HardwareEstimate(conn).historyReport.removeHistoryReport(data);
                    break;
            }
            tree_provider_1.default.instance.refresh();
        }
        catch (e) {
            vscode_api_1.default.catchError(e);
        }
    }));
    // 展示历史报告
    panel.receive('read-html', (report) => __awaiter(this, void 0, void 0, function* () {
        yield vscode_api_1.default.executeCMD(global_constants_1.EXT_COMMANDS.showReport, report);
    }));
    // 读取指定目录内文件
    panel.receive('read-dir', (dir) => __awaiter(this, void 0, void 0, function* () {
        const res = fs.readdirSync(dir);
        panel.postMsg({
            command: 'read-dir__success',
            data: res
        });
    }));
    // 下载历史报告
    panel.receive('download-history-item', (pathObj) => __awaiter(this, void 0, void 0, function* () {
        vscode_api_1.default.userLog('下载历史报告到:' + pathObj.localfilePath);
        vscode_api_1.default.writeLog('info', '准备下载历史报告');
        const readStream = fs.createReadStream(pathObj.vscodePath);
        const tream = fs.createWriteStream(pathObj.localfilePath);
        readStream.on('data', (chunk) => {
            tream.write(chunk);
        });
        readStream.on('end', () => {
            vscode_api_1.default.writeLog('info', '历史报告下载完毕，路径：' + pathObj.localfilePath);
            vscode_api_1.default.showMsg(vscode_api_2.I18nReplace('common_tip.download_successful', {
                cmd: pathObj
                    .localfilePath
                    .replace(/\//g, '\\')
            }));
            tream.end();
        });
    }));
    // 发送服务器信息
    panel.receive('get-server', () => __awaiter(this, void 0, void 0, function* () {
        request_1.createResponse(panel, 'get-server', true, {
            active: server_manage_1.serverManage.active,
            serverArray: server_manage_1.serverManage.serverArray,
            form: server_manage_1.serverManage.formData
        });
        server_manage_1.serverManage.formData = '';
    }));
}
exports.registerEvent = registerEvent;
//# sourceMappingURL=msg_handler.js.map