"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.subCommands = exports.init = void 0;
const vscode = require("vscode");
const vscode_api_1 = require("../vscode_api");
const vscode_api_2 = require("../vscode_api/vscode_api");
const global_constants_1 = require("../consts/global_constants");
const tree_provider_1 = require("../tree_provider");
const webview_provider_1 = require("../webview_provider");
const server_manage_1 = require("../server_manage");
const history_report_1 = require("../history_report");
const server_estimate_1 = require("../server_estimate");
const ssh2tool_1 = require("../ssh2tool");
const msg_handler_1 = require("../msg_manager/msg_handler");
const crypto_1 = require("../crypto");
const file_util_1 = require("../utils/file_util");
const fs = require("fs");
const base_util_1 = require("../utils/base_util");
const path_1 = require("path");
let wp;
let context;
function init(_context) {
    context = _context;
    // 设置插件路径
    vscode_api_1.default.setContextPath(context.extensionPath);
    // 清除服务器信息
    server_manage_1.serverManage.clearActive();
    // 初始化webview管理类
    wp = new webview_provider_1.WebviewProvider();
    // 首页配置
    wp.newTab('deploy/easy');
    // wp.newTab('relation-diagram');
}
exports.init = init;
// 检测是否存在本地的免责声明的数据
function testDisclaimData() {
    const fileContent = file_util_1.loadFile('extension_state.json');
    const usrDisClaimData = JSON.parse(fileContent);
    return usrDisClaimData.claimFlag;
}
// 左树下载报告
function downloadReport(localPath, filePath) {
    vscode_api_1.default.userLog('下载历史报告到:' + localPath);
    vscode_api_1.default.writeLog('info', '准备下载历史报告');
    const readStream = fs.createReadStream(filePath);
    const tream = fs.createWriteStream(localPath);
    readStream.on('data', (chunk) => {
        tream.write(chunk);
    });
    readStream.on('end', () => {
        vscode_api_1.default.writeLog('info', '历史报告下载完毕，路径：' + localPath);
        vscode_api_1.default.showMsg(vscode_api_2.I18nReplace('common_tip.download_successful', {
            cmd: localPath
                .replace(/\//g, '\\')
        }));
        tream.end();
    });
}
function subCommands() {
    // 首页侧边栏一键部署入口
    context.subscriptions.push(vscode_api_1.default.registerCMD(global_constants_1.EXT_COMMANDS.deployEasy, () => __awaiter(this, void 0, void 0, function* () {
        const res = testDisclaimData();
        try {
            if (!res) {
                yield wp.newTab('deploy/tool');
            }
            else {
                yield wp.newTab('deploy/easy');
            }
        }
        catch (e) {
            vscode_api_1.default.catchError(e);
        }
    })));
    // 配置远端服务器
    context.subscriptions.push(vscode_api_1.default.registerCMD(global_constants_1.EXT_COMMANDS.deployRemoteServer, () => __awaiter(this, void 0, void 0, function* () {
        const res = testDisclaimData();
        try {
            if (!res) {
                let panel = yield wp.newTab();
                server_manage_1.serverManage.sendServer(panel, 'create');
            }
            else {
                yield wp.newTab('deploy/easy');
            }
        }
        catch (e) {
            vscode_api_1.default.catchError(e);
        }
    })));
    // 切换服务器
    context.subscriptions.push(vscode_api_1.default.registerCMD(global_constants_1.EXT_COMMANDS.editServer, (data) => __awaiter(this, void 0, void 0, function* () {
        try {
            let panel = yield wp.newTab();
            crypto_1.getPwd(data.info.username, data.info.serverMark, (msg) => {
                if (typeof (msg) === 'string') {
                    data.info.password = '......';
                }
                else {
                    data.info.password = '';
                }
            });
            if (data && data.info) {
                server_manage_1.serverManage.sendServer(panel, 'edit', data);
            }
        }
        catch (e) {
            vscode_api_1.default.catchError(e);
        }
    })));
    // 一键连接
    context.subscriptions.push(vscode_api_1.default.registerCMD(global_constants_1.EXT_COMMANDS.connectServer, (data) => __awaiter(this, void 0, void 0, function* () {
        let active = server_manage_1.serverManage.active;
        if (Object.keys(active).length !== 0) {
            const ans = yield vscode_api_1.default.showMsg(vscode_api_2.I18n.common_server_manage.switch_tip, vscode_api_2.I18n.common_tip.confirm, vscode_api_2.I18n.common_tip.cancel);
            if (ans === vscode_api_2.I18n.common_tip.confirm) {
                msg_handler_1.immediateConnect(data);
            }
        }
        else {
            msg_handler_1.immediateConnect(data);
        }
    })));
    // 打开软件评估页面
    context.subscriptions.push(vscode_api_1.default.registerCMD(global_constants_1.EXT_COMMANDS.newSoftEstimate, () => __awaiter(this, void 0, void 0, function* () {
        try {
            yield wp.newTab('deploy/estimate/software');
        }
        catch (e) {
            vscode_api_1.default.catchError(e);
        }
    })));
    // 打开配置评估页面
    context.subscriptions.push(vscode_api_1.default.registerCMD(global_constants_1.EXT_COMMANDS.newConfigEstimate, () => __awaiter(this, void 0, void 0, function* () {
        try {
            yield wp.newTab('deploy/estimate/config');
        }
        catch (e) {
            vscode_api_1.default.catchError(e);
        }
    })));
    // 打开硬件评估页面
    context.subscriptions.push(vscode_api_1.default.registerCMD(global_constants_1.EXT_COMMANDS.newHardEstimate, () => __awaiter(this, void 0, void 0, function* () {
        try {
            yield wp.newTab('deploy/estimate/hardware');
        }
        catch (e) {
            vscode_api_1.default.catchError(e);
        }
    })));
    // 点击左侧目录删除执行操作
    context.subscriptions.push(vscode_api_1.default.registerCMD(global_constants_1.EXT_COMMANDS.deleteReport, (data) => __awaiter(this, void 0, void 0, function* () {
        let conn = new ssh2tool_1.default.SSH2Client(server_manage_1.serverManage.active.serverMark);
        vscode_api_1.default
            .writeLog('info', '删除历史报告' + data.name)
            .userLog('删除历史报告' + data.name);
        const arr = ['software', 'config', 'hardware', 'installed'];
        try {
            // 删除的是评估软件还是配置收集和评估还是硬件评估
            let deleteWare = arr.filter((item) => data.path.indexOf(`\\${item}\\`) > -1 || data.path.indexOf(`/${item}/`) > -1)[0];
            if (deleteWare == 'installed') {
                deleteWare = 'software';
            }
            const panel = wp.getPanelByTitle(global_constants_1.PANEL_TITLE[`deploy/estimate/${deleteWare}`]);
            if (panel && panel.view.visible) {
                panel.postMsg({
                    command: 'left-delete-item',
                    data: {
                        deleteData: data,
                        name: data.name,
                        ware: deleteWare
                    }
                });
            }
            else {
                const ans = yield vscode_api_1.default.showMsg(vscode_api_2.I18nReplace('common_tip.delete_confirm', { cmd: data.name }), vscode_api_2.I18n.common_tip.confirm, vscode_api_2.I18n.common_tip.cancel);
                if (ans === vscode_api_2.I18n.common_tip.confirm) {
                    let deleteData = {
                        name: data.name,
                        deletePath: deleteWare == 'software' ? data.dir : data.path
                    };
                    switch (deleteWare) {
                        case 'software':
                            yield new server_estimate_1.SoftwareEstimate(conn).historyReport.removeHistoryReport(deleteData);
                            break;
                        case 'config':
                            yield new server_estimate_1.DeployEstimate(conn).historyReport.removeHistoryReport(deleteData);
                            break;
                        case 'hardware':
                            yield new server_estimate_1.HardwareEstimate(conn).historyReport.removeHistoryReport(deleteData);
                            break;
                    }
                    vscode_api_1.default.showMsg(vscode_api_2.I18n.common_tip.delete_successfully);
                }
            }
        }
        catch (e) {
            vscode_api_1.default.catchError(e);
        }
        tree_provider_1.default.instance.refresh();
    })));
    // 清空左侧目录的历史报告
    context.subscriptions.push(vscode_api_1.default.registerCMD(global_constants_1.EXT_COMMANDS.clearReports, (data) => __awaiter(this, void 0, void 0, function* () {
        let conn = new ssh2tool_1.default.SSH2Client(server_manage_1.serverManage.active.serverMark);
        let ware = '';
        let reportList;
        try {
            switch (data.label) {
                case vscode_api_2.I18n.common_pannel_title.soft_evaluation:
                    ware = 'software';
                    reportList = yield new server_estimate_1.SoftwareEstimate(conn).historyReport.reportList;
                    break;
                case vscode_api_2.I18n.common_pannel_title.hard_evaluation:
                    ware = 'hardware';
                    reportList = yield new server_estimate_1.HardwareEstimate(conn).historyReport.reportList;
                    break;
                default:
                    ware = 'config';
                    reportList = yield new server_estimate_1.DeployEstimate(conn).historyReport.reportList;
                    break;
            }
            if (!reportList.length)
                return;
            vscode_api_1.default
                .writeLog('info', '清空历史报告')
                .userLog(`准备清空历史报告，共计：${reportList.length}条`);
            const panel = wp.getPanelByTitle(global_constants_1.PANEL_TITLE[`deploy/estimate/${ware}`]);
            if (panel && panel.view.visible) {
                panel.postMsg({
                    command: 'left-delete-item',
                    data: { reportList, ware }
                });
            }
            else {
                const ans = yield vscode_api_1.default.showMsg(vscode_api_2.I18nReplace('common_tip.clear_confirm', { cmd: data.label }), vscode_api_2.I18n.common_tip.confirm, vscode_api_2.I18n.common_tip.cancel);
                if (ans === vscode_api_2.I18n.common_tip.confirm) {
                    yield Promise.all([...reportList].map((report) => {
                        let deleteData = {
                            name: report.name,
                            deletePath: ware == 'software' ? report.dir : report.path
                        };
                        switch (ware) {
                            case 'software':
                                new server_estimate_1.SoftwareEstimate(conn).historyReport.removeHistoryReport(deleteData);
                                break;
                            case 'config':
                                new server_estimate_1.DeployEstimate(conn).historyReport.removeHistoryReport(deleteData);
                                break;
                            case 'hardware':
                                new server_estimate_1.HardwareEstimate(conn).historyReport.removeHistoryReport(deleteData);
                                break;
                        }
                    }));
                    vscode_api_1.default.showMsg(vscode_api_2.I18n.common_tip.clear_succesfully);
                }
            }
        }
        catch (e) {
            vscode_api_1.default.catchError(e);
        }
        tree_provider_1.default.instance.refresh();
    })));
    // 查看历史报告
    context.subscriptions.push(vscode_api_1.default.registerCMD(global_constants_1.EXT_COMMANDS.showReport, (data) => __awaiter(this, void 0, void 0, function* () {
        if (!data.path)
            return;
        const arr = ['software', 'config', 'hardware', 'installed'];
        let showWare = arr.filter((item) => data.path.indexOf(`\\${item}\\`) > -1 || data.path.indexOf(`/${item}/`) > -1)[0];
        if (showWare == 'software' && data.scanType == 'batch') {
            wp.newTab('report-list', true, {
                data: {
                    listInfo: data
                }
            });
        }
        else if (showWare == 'installed' && data.scanType) {
            const relationData = yield file_util_1.readFileAsync(path_1.join(data.dir, 'relationship.json'), 'utf-8');
            wp.newTab('relation-diagram', true, {
                data: {
                    dir: data.dir,
                    msg: relationData
                }
            });
        }
        else {
            const hash = {
                '(software)|(installed)': 'soft',
                config: 'conf',
                hardware: 'hard'
            };
            let page = '';
            if (showWare) {
                page = `report/${hash[showWare]}-result`;
            }
            try {
                const htmlStr = yield history_report_1.getLocalHTML(data.path);
                const htmlData = htmlStr;
                wp.newTab(page, true, {
                    data: {
                        msg: htmlData,
                        download: {
                            name: data.name,
                            path: data.path,
                            stat: {
                                birthtime: data.date
                            }
                        }
                    }
                });
            }
            catch (e) {
                vscode_api_1.default.catchError(e);
            }
        }
    })));
    // 下载html报告
    context.subscriptions.push(vscode_api_1.default.registerCMD(global_constants_1.EXT_COMMANDS.downloadHtml, (data) => __awaiter(this, void 0, void 0, function* () {
        if (!data.path)
            return;
        const pathArray = data.path.split(base_util_1.detectOS() === 'linux' ? '/' : '\\');
        let fileName = data.contextValue == 'softwareReport' ? pathArray[pathArray.length - 1] : data.name;
        const uri = yield vscode_api_1.default.showSaveDialog({
            defaultUri: vscode.Uri.file(fileName)
        });
        if (uri) {
            let localPath = base_util_1.detectOS() === 'linux' ? uri.path : uri.path.substr(1);
            downloadReport(localPath, data.path);
        }
    })));
    // 下载excel报告
    context.subscriptions.push(vscode_api_1.default.registerCMD(global_constants_1.EXT_COMMANDS.downloadExcel, (data) => __awaiter(this, void 0, void 0, function* () {
        if (!data.excelPath)
            return;
        const pathArray = data.excelPath.split(base_util_1.detectOS() === 'linux' ? '/' : '\\');
        const uri = yield vscode_api_1.default.showSaveDialog({
            defaultUri: vscode.Uri.file(pathArray[pathArray.length - 1])
        });
        if (uri) {
            let localPath = base_util_1.detectOS() === 'linux' ? uri.path : uri.path.substr(1);
            downloadReport(localPath, data.excelPath);
        }
    })));
    // 删除服务器记录
    context.subscriptions.push(vscode_api_1.default.registerCMD(global_constants_1.EXT_COMMANDS.deleteServer, (data) => __awaiter(this, void 0, void 0, function* () {
        try {
            let conn = new ssh2tool_1.default.SSH2Client(server_manage_1.serverManage.active.serverMark);
            vscode_api_1.default.writeLog('info', '删除服务器' + data.label);
            const ans = yield vscode_api_1.default.showMsg(vscode_api_2.I18n.common_server_manage.delete_server_confirm, vscode_api_2.I18n.common_tip.confirm, vscode_api_2.I18n.common_tip.cancel);
            if (ans === vscode_api_2.I18n.common_tip.confirm) {
                server_manage_1.serverManage.deleteServer(data);
                vscode_api_1.default.showMsg(vscode_api_2.I18n.common_tip.delete_successfully);
                if (data.label === server_manage_1.serverManage.active.serverMark) {
                    server_manage_1.serverManage.clearActive();
                    conn.disconnect();
                    let page = yield wp.newTab('deploy/server');
                    server_manage_1.serverManage.sendServer(page, 'create');
                    wp.closeViewByID(view => view.id !== page.id && !view.stored.deploy);
                    const disposable = vscode_api_1.default.registerTreeProvider('x2openEuler', tree_provider_1.default.createTree());
                    tree_provider_1.default.setTreeDispose(disposable);
                }
                crypto_1.delUser(data.info.username, data.label);
            }
        }
        catch (e) {
            vscode_api_1.default.catchError(e);
        }
        tree_provider_1.default.instance.refresh();
    })));
    // 清空服务器记录
    context.subscriptions.push(vscode_api_1.default.registerCMD(global_constants_1.EXT_COMMANDS.clearServers, () => __awaiter(this, void 0, void 0, function* () {
        try {
            if (server_manage_1.serverManage.serverArray.length === 0)
                return;
            let conn = new ssh2tool_1.default.SSH2Client(server_manage_1.serverManage.active.serverMark);
            const ans = yield vscode_api_1.default.showMsg(vscode_api_2.I18n.common_server_manage.clear_server_confirm, vscode_api_2.I18n.common_tip.confirm, vscode_api_2.I18n.common_tip.cancel);
            if (ans === vscode_api_2.I18n.common_tip.confirm) {
                server_manage_1.serverManage.serverArray.forEach(item => {
                    crypto_1.delUser(item.username, item.serverMark);
                });
                server_manage_1.serverManage.clearServer();
                conn.disconnect();
                let page = yield wp.newTab('deploy/server');
                server_manage_1.serverManage.sendServer(page, 'create');
                wp.closeViewByID(view => view.id !== page.id && !view.stored.deploy);
                vscode_api_1.default.showMsg(vscode_api_2.I18n.common_tip.clear_successfully);
                const disposable = vscode_api_1.default.registerTreeProvider('x2openEuler', tree_provider_1.default.createTree());
                tree_provider_1.default.setTreeDispose(disposable);
            }
        }
        catch (e) {
            vscode_api_1.default.catchError(e);
        }
    })));
}
exports.subCommands = subCommands;
//# sourceMappingURL=process.js.map