"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.HardwareEstimate = exports.DeployEstimate = exports.SoftwareEstimate = exports.ServerEstimate = void 0;
const os = require("os");
const path_1 = require("path");
const fs = require("fs");
const path = require("path");
const fs_1 = require("fs");
const compressing = require("compressing");
const vscode_api_1 = require("../vscode_api");
const vscode_api_2 = require("../vscode_api/vscode_api");
const Subscribe_1 = require("../utils/Subscribe");
const file_util_1 = require("../utils/file_util");
const base_util_1 = require("../utils/base_util");
const polling_util_1 = require("../utils/polling_util");
const global_constants_1 = require("../consts/global_constants");
const vscode_api_3 = require("../vscode_api/vscode_api");
const tree_provider_1 = require("../tree_provider");
const webview_provider_1 = require("../webview_provider");
const ssh2tools_1 = require("../ssh2tool/ssh2tools");
const history_report_1 = require("../history_report");
const util_1 = require("./util");
const HandleWebviewEvents_1 = require("../msg_manager/HandleWebviewEvents");
const estimate_config_1 = require("../server_estimate/estimate.config");
const base_util_2 = require("../utils/base_util");
let softwareReport = {};
let configReport = {};
let hardwareReport = {};
const checkExcelFlag = polling_util_1.createCheckFlag({
    success: /The excel report is saved/
});
const checkHtmlFlag = polling_util_1.createCheckFlag({
    success: /The report for/
});
const checkSuccessFlag = polling_util_1.createCheckFlag({
    success: /Analyse finished/
});
const checkTarFlag = polling_util_1.createCheckFlag({
    success: /The Archive file results are saved/
});
// 服务器评估类
class ServerEstimate {
    constructor(type, conn) {
        this._type = type;
        this.conn = conn;
    }
    static x2openEulerExists(conn) {
        let res = '';
        return new Promise((resolve, reject) => {
            util_1.getBaseCMD(conn)
                .then((cmd) => {
                return conn.exeCMDRemote(`${cmd} -v`, {
                    onData: (data) => {
                        res += data;
                    }
                });
            })
                .then(() => {
                resolve(res);
            }).catch((e) => {
                reject(e.message);
            });
        });
    }
    /**
     * 上传进程
     * @param options 上传文件的各种配置信息
     * @returns 上传的文件的格式化对象
     */
    static uploadProgress(options) {
        return __awaiter(this, void 0, void 0, function* () {
            const sftp = new ssh2tools_1.Sftp(options.conn);
            // 上传框设置
            if (options.settings) {
                vscode_api_1.default.setProgressOption(options.settings);
            }
            let res = null;
            try {
                // 提取文件信息
                const fileObj = yield file_util_1.transUri2File(options.uri, options.isDir);
                res = fileObj;
                // 文件类型、大小检测
                const check = yield util_1.checkFileType[options.type](fileObj);
                util_1.isErrorFile(check, fileObj, options.type);
                let containSpecial = new RegExp(/[(\~)(\!)(\@)(\#)(\$)(\%)(\^)(\&)(\*)(\()(\))(\=)(\[)(\])(\{)(\})(\|)(\\)(\;)(\:)(\')(\")(\,)(\/)(\<)(\>)(\?)(\)]+/);
                if (containSpecial.test(fileObj.name)) {
                    vscode_api_1.default.errMsg(vscode_api_3.I18n.common_file_error.cannot_special_symbols);
                    return;
                }
                // 文件名处理
                fileObj.name = util_1.handleFileName(fileObj.name);
                // 重名检测
                const remotePath = options.dir + fileObj.name;
                const ispackExists = yield sftp.packExists(remotePath);
                // 重名或者覆盖标识为false，中断上传
                if (ispackExists && options.overwrite === false) {
                    return Object.assign(Object.assign({}, options), { fileObj });
                }
                else {
                    yield vscode_api_1.default.showProgress((p, t) => __awaiter(this, void 0, void 0, function* () {
                        t.onCancellationRequested(() => {
                            vscode_api_1.default.errMsg(vscode_api_3.I18n.common_tip.cancel_upload);
                            vscode_api_1.default.userLog(vscode_api_3.I18n.common_tip.cancel_upload);
                        });
                        try {
                            yield util_1.handleUpload(options.conn, options.isDir, fileObj, remotePath, p, t);
                        }
                        catch (e) {
                            throw e;
                        }
                        yield base_util_1.delayFunc(() => {
                            p.report({
                                increment: 0,
                                message: '100.00%'
                            });
                        }, 0.1 * global_constants_1.SECOND);
                    }));
                    return res;
                }
            }
            catch (e) {
                throw e;
            }
        });
    }
    /**
     * 评估结束
     * @param type 评估结果
     * @param html html文件信息（如果有）
     * @param panel 评估进程对应的页面
     */
    estimateEnd(type, html, panel) {
        const htmlData = html ? html.content : '';
        panel.postMsg({
            command: type,
            data: {
                msg: htmlData,
                download: html
            }
        });
    }
    /**
     * 评估结果是tar包
     * @param res 评估成功的信息
     * @param panel 处理页
     */
    getTarSuccess(res, panel) {
        const tarInfo = this.getRemoteSrc(res);
        const tarPath = tarInfo.remotePath;
        const tarName = tarInfo.fileName;
        panel.stored.evaluationStatus = 'succeed';
        panel.receive('download-file', (data) => __awaiter(this, void 0, void 0, function* () {
            panel.unreceive('download-file');
            try {
                yield this.downloadRemoteSrc({
                    localPath: data.msg,
                    remotePath: tarPath
                }, 'tar');
                panel.view.dispose();
            }
            catch (e) {
                throw e;
            }
        }));
        const sendMsg = {
            command: this._type === 'config' ? 'collect-success' : 'bin-success',
            data: tarName
        };
        Subscribe_1.default.on('page-prepared', () => {
            Subscribe_1.default.off('page-prepared');
            panel.postMsg(sendMsg);
        });
        panel.postMsg(sendMsg);
    }
    /**
     * 评估结果是html页面
     * @param res 评估成功的信息
     * @param panel 处理页
     */
    getHTMLSuccess(res, panel) {
        return __awaiter(this, void 0, void 0, function* () {
            let excel;
            let htmlInfo;
            panel.stored.evaluationStatus = 'succeed';
            if (this._type == 'software') {
                htmlInfo = this.getRemoteSrc(res.html);
                let excelInfo = this.getRemoteSrc(res.excel);
                yield this.downloadRemoteSrc(excelInfo);
                excel = file_util_1.getFileFormat(excelInfo.localPath);
            }
            else {
                htmlInfo = this.getRemoteSrc(res);
                htmlInfo.localPath = path_1.join(htmlInfo.localDir, htmlInfo.dirName + '.html');
            }
            try {
                yield this.downloadRemoteSrc(htmlInfo);
            }
            catch (e) {
                throw e;
            }
            const htmlLocalPath = htmlInfo.localPath;
            const html = file_util_1.getFileFormat(htmlLocalPath);
            if (html.err) {
                vscode_api_1.default.msgNlog('error', '返回评估报告失败，原因：' + html.err);
                this.estimateFail(panel);
                return;
            }
            const displayName = this._type == 'software' ? htmlInfo.dirName : html.name;
            const pushRes = this.historyReport.pushReport({
                name: displayName,
                path: html.path,
                excelPath: excel ? excel.path : '',
                date: new Date(html.stat.ctime),
                scanType: res.scanType ? res.scanType : '',
                dir: htmlInfo.localDir
            });
            if (pushRes) {
                vscode_api_1.default.msgNlog('error', vscode_api_3.I18n.common_file_error.capacity_insufficient);
            }
            else {
                tree_provider_1.default.instance.refresh();
                this.postReport();
            }
            /**
             * estimateEnd不会执行两次，
             * 1、正常情况，webview页面准备完成发送page-prepared事件，Subscribe ‘page-prepared’还未订阅，后端评估还在进行， ‘page-prepared’ 不会执行
             * 2、后端评估已成功  webview页面准备还未完成， extension 发送 html-success 消息不会执行， webview页面准备完成会发送 page-prepared 事件  执行 html-success
             */
            Subscribe_1.default.on('page-prepared', () => {
                Subscribe_1.default.off('page-prepared');
                this.estimateEnd('html-success', html, panel);
                HandleWebviewEvents_1.handleReportDownload(panel, { name: displayName, path: html.path, });
            });
            this.estimateEnd('html-success', html, panel);
            HandleWebviewEvents_1.handleReportDownload(panel, { name: displayName, path: html.path, });
        });
    }
    /**
     * 评估失败
     * @param panel 处理页
     */
    estimateFail(panel) {
        panel.stored.evaluationStatus = 'failed';
        this.estimateEnd('html-fail', undefined, panel);
    }
    // 评估报告发送给评估页
    postReport() {
        const wp = new webview_provider_1.WebviewProvider();
        let page = wp.getPanelsByTitle(global_constants_1.PANEL_TITLE[`deploy/estimate/${this._type}`]);
        if (page.length != 0) {
            page[0].postMsg({
                command: 'update-history',
                data: {
                    msg: this.historyReport.reportList,
                    Introduction: estimate_config_1.server
                }
            });
        }
    }
    /**
     * 生成命令行
     * @param options
     */
    generateCMD(options) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const baseCMD = yield util_1.getBaseCMD(this.conn);
                const cmdStr = [baseCMD].concat(options);
                const cmd = cmdStr.join(' ');
                yield this.dispatchCMD(cmd);
            }
            catch (e) {
                throw e;
            }
        });
    }
    /**
     * 下发命令行
     * @param cmd 命令行
     */
    dispatchCMD(cmd) {
        return __awaiter(this, void 0, void 0, function* () {
            this.pp.postMsg({
                command: `${this._type}-estimate__success`
            });
            // 向服务器下发命令
            vscode_api_1.default.writeLog('info', '准备下发命令:' + cmd);
            vscode_api_1.default.writeOutput('', 'info', global_constants_1.ESTIMATE_TERMINAL[this._type], true, true);
            try {
                yield this.conn.exeCMDRemote(cmd, {
                    onErrData: (data) => {
                        vscode_api_1.default.writeOutput(data, 'debug', global_constants_1.ESTIMATE_TERMINAL[this._type], false, true);
                        this.checkProgress(data);
                    }
                });
                vscode_api_1.default.writeLog('info', '成功执行命令');
            }
            catch (e) {
                vscode_api_1.default.writeLog('info', '下发命令失败, 原因：' + e);
            }
        });
    }
    /**
     * 从远端标志命令中获取远端资源的信息
     * @param res 远端资源生成成功的命令
     * @returns 资源信息
     */
    getRemoteSrc(res) {
        const arr = res.split(':');
        const _remoteUrl = arr[arr.length - 1].trim();
        const _arr = _remoteUrl.split('/');
        const _name = _arr[_arr.length - 1].trim();
        const _dir = _arr[_arr.length - 2].trim();
        const { host, port, username } = this.conn.getServerInfo();
        let localDir;
        if (this._type == 'software') {
            localDir = path_1.join(vscode_api_1.default.extensionPath, base_util_1.toSha256(`${host}${port}${username}`), this._type, _dir);
        }
        else {
            localDir = path_1.join(vscode_api_1.default.extensionPath, base_util_1.toSha256(`${host}${port}${username}`), this._type);
        }
        const localPath = path_1.join(localDir, _name);
        return {
            remotePath: _remoteUrl,
            localPath,
            localDir,
            dirName: _dir,
            fileName: _name
        };
    }
    /**
     * 根据资源信息下载资源到本地
     * @param srcInfo 资源信息
     * @param srcType 资源类型
     * @returns PROCESS.STATUS
     */
    downloadRemoteSrc(srcInfo, srcType = 'html') {
        return __awaiter(this, void 0, void 0, function* () {
            const { remotePath, localDir, localPath } = srcInfo;
            if (localDir) {
                fs_1.mkdirSync(localDir, { recursive: true });
            }
            const sftp = new ssh2tools_1.Sftp(this.conn);
            let isDownloaded;
            try {
                isDownloaded = yield sftp.downloadFile({
                    remotePath,
                    localPath
                });
            }
            catch (err) {
                const e = base_util_2.setObjectPropertyEnumerable(err);
                vscode_api_1.default.writeLog('error', 'downloadRemoteSrc' + JSON.stringify(e));
                throw e;
            }
            if (srcType === 'html' && isDownloaded === 0 /* SUCCESS */) {
                vscode_api_1.default.writeLog('info', '历史报告保存到:' + localPath);
                return 0 /* SUCCESS */;
            }
            else if (isDownloaded === 0 /* SUCCESS */) {
                vscode_api_1.default.showMsg(vscode_api_2.I18nReplace('common_tip.download_successful', {
                    cmd: localPath.replace(/\//g, '\\')
                }));
                vscode_api_1.default.userLog('下载文件成功,文件位置:' + localPath);
                return 0 /* SUCCESS */;
            }
            else {
                vscode_api_1.default.userLog('下载文件失败');
                vscode_api_1.default.writeLog('error', '下载文件失败');
                return 1 /* FAILURE */;
            }
        });
    }
    initHistoryReport(report) {
        if (report[this.conn.getServerInfo().host]) {
            this.historyReport = report[this.conn.getServerInfo().host];
        }
        else {
            report[this.conn.getServerInfo().host] = new history_report_1.default(this._type);
            this.historyReport = report[this.conn.getServerInfo().host];
        }
    }
}
exports.ServerEstimate = ServerEstimate;
class SoftwareEstimate extends ServerEstimate {
    constructor(conn) {
        super('software', conn);
        this.initHistoryReport(softwareReport);
    }
    runEstimate(form, panel) {
        this.pp = panel;
        form.fileType === 'installed'
            ? this.runInstalledEstimate(form)
            : this.runLocalEstimate(form);
    }
    // 本地单文件评估
    runSingleEstimate(form) {
        return __awaiter(this, void 0, void 0, function* () {
            const remotePath = global_constants_1.WORK_DIR + form.externalFile;
            // 跳转页面等待评估
            try {
                const curPanel = yield new webview_provider_1.WebviewProvider().turnToProgress({ type: 'soft' });
                let htmlPath;
                let excelPath;
                curPanel.stored.evaluationStatus = 'evaluating';
                this.checkProgress = (data) => {
                    let dataArray = data.split('\n');
                    dataArray.map(item => {
                        if (checkHtmlFlag.success(item)) {
                            htmlPath = item;
                        }
                        else if (checkExcelFlag.success(item)) {
                            excelPath = item;
                        }
                        if (checkSuccessFlag.success(item)) {
                            if (polling_util_1.checkResult(item)) {
                                this.getHTMLSuccess({ html: htmlPath, excel: excelPath, scanType: form.scanType }, curPanel);
                            }
                            else {
                                this.estimateFail(curPanel);
                            }
                        }
                    });
                };
                this.generateCMD(['scan', `-arch ${form.arch}`, `-os_name ${form.osName}`, `-target_os_name ${form.targetOsName}`, remotePath]);
            }
            catch (e) {
                throw e;
            }
        });
    }
    // 已安装软件包评估
    runInstalledEstimate(form) {
        return __awaiter(this, void 0, void 0, function* () {
            // 跳转页面等待评估
            const curPanel = yield new webview_provider_1.WebviewProvider().turnToProgress({ type: 'soft' });
            curPanel.stored.evaluationStatus = 'evaluating';
            let scanData = '';
            if (form.scanType == 'single' && form.analyzeType == 'remote') {
                scanData = form.remote;
            }
            else {
                scanData = form.installedPackage;
            }
            let excelPath;
            let tarPath;
            this.checkProgress = (data) => __awaiter(this, void 0, void 0, function* () {
                let dataArray = data.split('\n');
                dataArray.map(item => {
                    if (checkExcelFlag.success(item)) {
                        excelPath = item;
                    }
                    else if (checkTarFlag.success(item)) {
                        tarPath = item;
                    }
                    if (checkSuccessFlag.success(item)) {
                        if (polling_util_1.checkResult(item)) {
                            this.depEstimateSuccess({ excelPath, tarPath, scanType: 'installed' }, curPanel);
                        }
                        else {
                            this.estimateFail(curPanel);
                        }
                    }
                });
            });
            yield this.generateCMD(['scan', '-l', scanData, `-arch ${form.arch}`, `-os_name ${form.osName}`, `-target_os_name ${form.targetOsName}`]);
        });
    }
    // 本地批量文件夹评估
    runBatchEstimate(form) {
        return __awaiter(this, void 0, void 0, function* () {
            const remotePath = global_constants_1.WORK_DIR + form.externalFile;
            try {
                const curPanel = yield new webview_provider_1.WebviewProvider().turnToProgress({ type: 'soft' });
                curPanel.stored.evaluationStatus = 'evaluating';
                let excelPath;
                let tarPath;
                this.checkProgress = (data) => __awaiter(this, void 0, void 0, function* () {
                    let dataArray = data.split('\n');
                    dataArray.map(item => {
                        if (checkExcelFlag.success(item)) {
                            excelPath = item;
                        }
                        else if (checkTarFlag.success(item)) {
                            tarPath = item;
                        }
                        if (checkSuccessFlag.success(item)) {
                            if (polling_util_1.checkResult(item) && tarPath) {
                                this.batchScanSuccess({ excelPath, tarPath, scanType: form.scanType }, curPanel);
                            }
                            else if (polling_util_1.checkResult(item) && !tarPath) {
                                let htmlPath = excelPath.substring(0, excelPath.length - 19) + '.html';
                                this.getHTMLSuccess({ html: htmlPath, excel: excelPath, scanType: 'single' }, curPanel);
                            }
                            else {
                                this.estimateFail(curPanel);
                            }
                        }
                    });
                });
                this.generateCMD(['scan', `-b`, `-arch ${form.arch}`, `-os_name ${form.osName}`, `-target_os_name ${form.targetOsName}`, remotePath]);
            }
            catch (e) {
                throw e;
            }
        });
    }
    /**
     * 将指定src目录下的所有文件剪切到指定目标dest目录下
     * @param src 源目录
     * @param dest 目标目录
     */
    copyDirectory(src, dest) {
        let files = fs.readdirSync(src);
        files.forEach(item => {
            let itemPath = path.join(src, item);
            let itemStat = fs.statSync(itemPath); // 获取文件信息
            let savedPath = path.join(dest, itemPath.replace(src, ''));
            let savedDir = savedPath.substring(0, savedPath.lastIndexOf(os.type() == 'Linux' ? '/' : '\\'));
            if (itemStat.isFile()) {
                // 如果目录不存在则进行创建
                if (!fs.existsSync(savedDir)) {
                    fs.mkdirSync(savedDir, { recursive: true });
                }
                // 写入到新目录下
                let data = fs.readFileSync(itemPath);
                fs.writeFileSync(savedPath, data);
                // 并且删除原文件
                fs.unlinkSync(itemPath);
            }
            else if (itemStat.isDirectory()) {
                this.copyDirectory(itemPath, path.join(savedDir, item));
            }
        });
        // 并且删除原目录
        // fs.rmdirSync(src);
    }
    // 已安装软件扫描成功
    depEstimateSuccess(data, panel) {
        return __awaiter(this, void 0, void 0, function* () {
            panel.stored.evaluationStatus = 'succeed';
            const excelDir = this.getRemoteSrc(data.excelPath);
            const tarDir = this.getRemoteSrc(data.tarPath);
            const { host, port, username } = this.conn.getServerInfo();
            const localDir = path_1.join(vscode_api_1.default.extensionPath, base_util_1.toSha256(`${host}${port}${username}`), 'installed', excelDir.dirName);
            const localPath = path_1.join(localDir);
            fs_1.mkdirSync(localPath, { recursive: true });
            let tarLocalPath = path_1.join(localPath, tarDir.fileName);
            try {
                const isDownloaded = yield this.downloadRemoteSrc({ localPath: tarLocalPath,
                    remotePath: tarDir.remotePath
                });
                try {
                    yield compressing.tgz.uncompress(tarLocalPath, localPath);
                    this.copyDirectory(tarLocalPath.replace(/.tar.gz$/, ''), localPath);
                }
                catch (err) {
                    vscode_api_1.default.writeLog('error', 'depEstimateSuccess-compressing-copyDirectory' + JSON.stringify(base_util_2.setObjectPropertyEnumerable(err)));
                }
                const relationData = yield file_util_1.readFileAsync(path_1.join(localPath, 'relationship.json'), 'utf-8');
                let installedData = {
                    msg: relationData,
                    dir: localPath
                };
                let report = file_util_1.getFileFormat(tarLocalPath);
                let reportData = {
                    name: excelDir.dirName,
                    path: tarLocalPath,
                    excelPath: path_1.join(localPath, excelDir.fileName),
                    date: new Date(report.stat.birthtime),
                    scanType: data.scanType,
                    dir: localPath
                };
                const pushRes = this.historyReport.pushReport(reportData);
                if (pushRes) {
                    vscode_api_1.default.msgNlog('error', vscode_api_3.I18n.common_file_error.capacity_insufficient);
                }
                else {
                    tree_provider_1.default.instance.refresh();
                    this.postReport();
                }
                if (isDownloaded === 0 /* SUCCESS */) {
                    Subscribe_1.default.on('page-prepared', () => {
                        Subscribe_1.default.off('page-prepared');
                        panel.postMsg({
                            command: 'installed-success',
                            data: installedData
                        });
                    });
                    panel.postMsg({
                        command: 'installed-success',
                        data: installedData
                    });
                }
            }
            catch (err) {
                const e = base_util_2.setObjectPropertyEnumerable(err);
                vscode_api_1.default.writeLog('error', 'depEstimateSuccess' + JSON.stringify(e));
                throw e;
            }
        });
    }
    // 软件包批量扫描成功
    batchScanSuccess(data, panel) {
        return __awaiter(this, void 0, void 0, function* () {
            panel.stored.evaluationStatus = 'succeed';
            const excelInfo = this.getRemoteSrc(data.excelPath);
            const tarInfo = this.getRemoteSrc(data.tarPath);
            let report;
            fs_1.mkdirSync(excelInfo.localDir, { recursive: true });
            let tarLocalPath = path_1.join(excelInfo.localDir, tarInfo.fileName);
            try {
                yield this.downloadRemoteSrc({ localPath: tarLocalPath,
                    remotePath: tarInfo.remotePath
                });
                try {
                    yield compressing.tgz.uncompress(tarLocalPath, excelInfo.localDir);
                    this.copyDirectory(tarLocalPath.replace(/.tar.gz$/, ''), excelInfo.localDir);
                }
                catch (e) {
                    vscode_api_1.default.writeLog('error', 'batchScanSuccess-compressing-copyDirectory' + JSON.stringify(base_util_2.setObjectPropertyEnumerable(e)));
                }
                report = file_util_1.getFileFormat(excelInfo.localPath);
                let reportData = {
                    name: excelInfo.dirName,
                    path: tarLocalPath,
                    excelPath: excelInfo.localPath,
                    date: new Date(report.stat.birthtime),
                    scanType: data.scanType,
                    dir: excelInfo.localDir
                };
                const pushRes = this.historyReport.pushReport(reportData);
                if (pushRes) {
                    vscode_api_1.default.msgNlog('error', vscode_api_3.I18n.common_file_error.capacity_insufficient);
                }
                else {
                    tree_provider_1.default.instance.refresh();
                    this.postReport();
                }
                Subscribe_1.default.on('page-prepared', () => {
                    Subscribe_1.default.off('page-prepared');
                    panel.postMsg({
                        command: 'html-success',
                        data: {
                            listInfo: reportData
                        }
                    });
                    HandleWebviewEvents_1.handleReportDownload(panel, { name: excelInfo.dirName, path: excelInfo.localPath, });
                });
                panel.postMsg({
                    command: 'html-success',
                    data: {
                        listInfo: reportData
                    }
                });
                HandleWebviewEvents_1.handleReportDownload(panel, { name: excelInfo.dirName, path: excelInfo.localPath, });
            }
            catch (err) {
                const e = base_util_2.setObjectPropertyEnumerable(err);
                vscode_api_1.default.writeLog('error', 'batchScanSuccess' + JSON.stringify(e));
                throw e;
            }
        });
    }
    // 本地文件评估
    runLocalEstimate(form) {
        return __awaiter(this, void 0, void 0, function* () {
            // 单文件还是批量bin
            form.scanType === 'single'
                ? this.runSingleEstimate(form)
                : this.runBatchEstimate(form);
        });
    }
}
exports.SoftwareEstimate = SoftwareEstimate;
class DeployEstimate extends ServerEstimate {
    constructor(conn) {
        super('config', conn);
        this.initHistoryReport(configReport);
    }
    runLocalScan(form) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const curPanel = yield new webview_provider_1.WebviewProvider().turnToProgress({ type: 'conf', taskType: form.taskType });
                curPanel.stored.evaluationStatus = 'evaluating';
                const checkFlag = polling_util_1.createCheckFlag({
                    success: /The report for/
                });
                this.checkProgress = (data) => {
                    if (checkFlag.success(data)) {
                        this.getHTMLSuccess(data, curPanel);
                    }
                    else if (checkFlag.failure(data)) {
                        this.estimateFail(curPanel);
                    }
                };
                this.generateCMD(['conf-analyse', `-os_name ${form.osName}`, `-target_os_name ${form.targetOsName}`, '-local']);
                return true;
            }
            catch (e) {
                throw e;
            }
        });
    }
    runLoadScan(form) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const remotePath = global_constants_1.WORK_DIR + form.externalFile;
                const curPanel = yield new webview_provider_1.WebviewProvider().turnToProgress({ type: 'conf', taskType: 'scan' });
                curPanel.stored.evaluationStatus = 'evaluating';
                const checkFlag = polling_util_1.createCheckFlag({
                    success: /The report for/
                });
                this.checkProgress = (data) => {
                    if (checkFlag.success(data)) {
                        this.getHTMLSuccess(data, curPanel);
                    }
                    else if (checkFlag.failure(data)) {
                        this.estimateFail(curPanel);
                    }
                };
                this.generateCMD(['conf-analyse', `-arch ${form.arch}`, `-os_name ${form.osName}`, `-target_os_name ${form.targetOsName}`, '-load', remotePath]);
            }
            catch (e) {
                throw e;
            }
        });
    }
    runConfScan(form) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                (yield form.scanType) === 'local'
                    ? this.runLocalScan(form)
                    : this.runLoadScan(form);
            }
            catch (e) {
                throw e;
            }
        });
    }
    runConfCollect() {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const curPanel = yield new webview_provider_1.WebviewProvider().turnToProgress({ type: 'conf', taskType: 'collect' });
                curPanel.stored.evaluationStatus = 'evaluating';
                const checkFlag = polling_util_1.createCheckFlag({
                    success: /Generate Success/
                });
                this.checkProgress = (data) => {
                    if (checkFlag.success(data)) {
                        this.getTarSuccess(data, curPanel);
                    }
                    else if (checkFlag.failure(data)) {
                        this.estimateFail(curPanel);
                    }
                };
                this.generateCMD(['conf-collect']);
                return true;
            }
            catch (e) {
                throw e;
            }
        });
    }
    runEstimate(form, panel) {
        this.pp = panel;
        form.taskType === '评估'
            ? this.runConfScan(form)
            : this.runConfCollect();
    }
}
exports.DeployEstimate = DeployEstimate;
class HardwareEstimate extends ServerEstimate {
    constructor(conn) {
        super('hardware', conn);
        this.initHistoryReport(hardwareReport);
    }
    runLocalInfo(form) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const curPanel = yield new webview_provider_1.WebviewProvider().turnToProgress({ type: 'hard' });
                curPanel.stored.evaluationStatus = 'evaluating';
                const checkFlag = polling_util_1.createCheckFlag({
                    success: /The report for/
                });
                this.checkProgress = (data) => {
                    if (checkFlag.success(data)) {
                        this.getHTMLSuccess(data, curPanel);
                    }
                    else if (checkFlag.failure(data)) {
                        this.estimateFail(curPanel);
                    }
                };
                this.generateCMD(['hardware-analyse', '-local']);
                return true;
            }
            catch (e) {
                throw e;
            }
        });
    }
    // 外部导入信息源
    runLoadInfo(form) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const remotePath = global_constants_1.WORK_DIR + form.externalFile;
                const curPanel = yield new webview_provider_1.WebviewProvider().turnToProgress({ type: 'hard', taskType: 'scan' });
                curPanel.stored.evaluationStatus = 'evaluating';
                const checkFlag = polling_util_1.createCheckFlag({
                    success: /The report for/
                });
                this.checkProgress = (data) => {
                    if (checkFlag.success(data)) {
                        this.getHTMLSuccess(data, curPanel);
                    }
                    else if (checkFlag.failure(data)) {
                        this.estimateFail(curPanel);
                    }
                };
                this.generateCMD(['hardware-analyse', '-load', remotePath]);
            }
            catch (e) {
                throw e;
            }
        });
    }
    runEstimate(form, panel) {
        this.pp = panel;
        form.hardwareInfo === 'local'
            ? this.runLocalInfo(form)
            : this.runLoadInfo(form);
    }
}
exports.HardwareEstimate = HardwareEstimate;
//# sourceMappingURL=server_estimate.js.map