"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ServerManage = void 0;
const fs = require("fs");
const path_1 = require("path");
const configJSONPath = path_1.join(__dirname, './server_data.json');
class ServerManage {
    constructor() {
        this.serverArray = this.getServerData().serverArray;
        this.active = this.getServerData().active;
    }
    // 获取服务器数据
    getServerData() {
        return JSON.parse(fs.readFileSync(configJSONPath, 'utf-8'));
    }
    // 写入服务器数据
    writeServerData() {
        const writeData = {
            serverArray: this.serverArray,
            active: this.active
        };
        fs.writeFileSync(configJSONPath, JSON.stringify(writeData), 'utf-8');
    }
    // 传递信息
    sendServer(panel, type, serverData) {
        let data = {};
        data.active = this.active;
        data.serverArray = this.serverArray;
        if (type === 'edit' && serverData) {
            serverData.info.username = 'x2openEuler';
            data.form = serverData.info;
            this.formData = serverData.info;
        }
        if (type === 'create') {
            data.form = '';
            this.formData = '';
        }
        panel.postMsg({
            command: 'server-switch',
            data
        });
    }
    // 新增服务器数据
    addServer(data) {
        let serverInfo = Object.assign({}, data);
        delete serverInfo.password;
        this.active = serverInfo;
        const exist = this.serverArray.some(server => server.serverMark === data.serverMark);
        if (!exist) {
            this.serverArray.push(serverInfo);
        }
        this.writeServerData();
        return this;
    }
    // 修改服务器记录
    modifyServer(data, backupData) {
        let serverInfo = Object.assign({}, data);
        delete serverInfo.password;
        for (let i = 0; i < this.serverArray.length; i++) {
            if (this.serverArray[i].serverMark === backupData.serverMark) {
                this.serverArray.splice(i, 1, serverInfo);
                break;
            }
        }
        this.active = serverInfo;
        this.writeServerData();
    }
    // 删除服务器记录
    deleteServer(data) {
        for (let i = 0; i < this.serverArray.length; i++) {
            if (this.serverArray[i].serverMark === data.label) {
                this.serverArray.splice(i, 1);
                break;
            }
        }
        this.writeServerData();
        return this;
    }
    // 清空服务器数据
    clearServer() {
        this.serverArray = [];
        this.active = {};
        this.writeServerData();
        return this;
    }
    // 清除活跃服务器
    clearActive() {
        this.active = {};
        this.writeServerData();
    }
}
exports.ServerManage = ServerManage;
//# sourceMappingURL=server_manager.js.map