"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TreeProvider = void 0;
const vscode = require("vscode");
const tree_item_1 = require("./tree_item");
const util_1 = require("./util");
class TreeProvider {
    constructor() {
        this._onDidChangeTreeData = new vscode.EventEmitter();
        this.onDidChangeTreeData = this._onDidChangeTreeData.event;
    }
    /**
     * 刷新树节点数据的方法
     * @returns this
     */
    refresh() {
        this._onDidChangeTreeData.fire();
        return this;
    }
    /**
     * 将数据转换为vscode树可渲染的数据结构
     * @param ele
     * @returns vscode.TreeItem
     */
    getTreeItem(element) {
        // 把TreeNode数据变为TreeItem
        return new tree_item_1.TreeItem(element);
    }
    /**
     * 获取节点的子节点
     * @param ele
     * @returns Array<TreeNode>
     */
    getChildren(element) {
        if (!element) {
            // 返回根节点
            return util_1.getRootItems();
        }
        else {
            if (element.childType === "report" /* REPORT */) {
                // 返回报告节点
                const _contextValue = element.contextValue;
                const arr = util_1.getReportItems(_contextValue);
                // 根据是否有报告数据返回空节点或者是报告列表节点
                return arr.length ? arr : [util_1.createVoidNode(element)];
            }
            else if (element.childType === "server" /* NOTCONNECTSERVER */ || element.childType === "connectServer" /* CONNECTSERVER */) {
                // 返回服务器节点
                return util_1.getServerItems();
            }
            else {
                // 没有别的类型
                return [];
            }
        }
    }
}
exports.TreeProvider = TreeProvider;
//# sourceMappingURL=tree_provider.js.map