"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.setObjectPropertyEnumerable = exports.detectOS = exports.getPartString = exports.toSha256 = exports.delayFunc = exports.callHooks = exports.generateCommand = exports.inWhiteList = exports.filterDate = exports.buf2String = exports.getObjectFromString = exports.camel2_name = exports.percentage = exports.getType = void 0;
const crypto = require("crypto");
/**
 * 返回一个数据的类型
 * @param ele
 * @returns
 */
function getType(ele) {
    return Object.prototype.toString.call(ele).split(' ')[1].slice(0, -1);
}
exports.getType = getType;
/**
 * 将分数化为百分数
 * @param x
 * @param y
 * @returns 100 * x / y
 */
function percentage(x, y) {
    return 100 * x / y;
}
exports.percentage = percentage;
/**
 * 驼峰转下划线
 * @param str
 * @returns
 */
function camel2_name(str) {
    return str.replace(/([A-Z])/g, (m, $1) => {
        return `_${$1.toLowerCase()}`;
    });
}
exports.camel2_name = camel2_name;
/**
 * 从字符串中获取对象
 * @param resStr 需要处理的字符串
 * @param char  strChar 分割处理字符串的字符，keyChar分割键名和键值的字符
 * @returns object resStr转化的对象
 */
function getObjectFromString(resStr, char = { strChar: '\n', keyChar: ':' }) {
    let { strChar, keyChar } = char;
    const propArr = resStr.split(strChar);
    return propArr.reduce((acc, cur) => {
        var _a, _b;
        const key = (_a = cur.split(keyChar)[0]) === null || _a === void 0 ? void 0 : _a.trim();
        const value = (_b = cur.split(keyChar)[1]) === null || _b === void 0 ? void 0 : _b.trim();
        if (key && value)
            acc[key] = value;
        return acc;
    }, {});
}
exports.getObjectFromString = getObjectFromString;
/**
 * 将可能的Buffer类型转化为string
 * @param buf可能的buffer数据
 * @returns string
 */
function buf2String(buf) {
    return (buf instanceof Buffer)
        ? Buffer.from(buf).toString()
        : buf;
}
exports.buf2String = buf2String;
// 格式化日期
function addZero(num) {
    return (num < 10 ? '0' : '') + num;
}
function filterDate(date, format = 'YYYY/MM/DD hh:mm:ss') {
    const Hours = date.getHours();
    const Minute = date.getMinutes();
    const Second = date.getSeconds();
    const Year = date.getFullYear();
    const Month = date.getMonth() + 1;
    const Day = date.getDate();
    return format
        .replace('YYYY', String(Year))
        .replace('MM', addZero(Month))
        .replace('DD', addZero(Day))
        .replace('hh', addZero(Hours))
        .replace('mm', addZero(Minute))
        .replace('ss', addZero(Second))
        .replace('M', String(Month))
        .replace('D', String(Day))
        .replace('h', String(Hours))
        .replace('m', String(Minute))
        .replace('s', String(Second));
}
exports.filterDate = filterDate;
/**
 * 返回目标是否在白名单中
 * @param target 被检验对象
 * @param whiteList 白名单
 * @returns boolean
 */
const type4WhiteList = {
    RegExp: (r, t) => {
        return r.test(t);
    },
    String: (r, t) => {
        return t.indexOf(r) !== -1;
    },
    Function: (r, t) => {
        return r(t);
    }
};
function inWhiteList(target, whiteList = []) {
    return whiteList.some(e => type4WhiteList[getType(e)](e, target));
}
exports.inWhiteList = inWhiteList;
/**
 * 选择性地拼接多段数据
 * @param params 数据数组
 * @param cb 判断当前数据是否添加的回调
 * @returns 拼接好的命令
 */
function generateCommand(params, cb) {
    return params.reduce((total, current) => cb(current) ? total.concat(current) : total, []).join(' ');
}
exports.generateCommand = generateCommand;
/**
 * 调用事件钩子
 * @param hookName
 * @param hooks
 * @param params
 * @returns void
 */
function callHooks(hookName, hooks, ...params) {
    if (!hooks)
        return;
    if (hooks[hookName] instanceof Function) {
        hooks[hookName](...params);
    }
}
exports.callHooks = callHooks;
/**
 * 延迟结束一个异步过程
 * @param fn 结束前调用的方法
 * @param delay 延迟时间
 * @returns Promise
 */
function delayFunc(fn, delay) {
    return __awaiter(this, void 0, void 0, function* () {
        return new Promise((resolve, reject) => {
            fn();
            setTimeout(() => {
                resolve('complete');
            }, delay);
        });
    });
}
exports.delayFunc = delayFunc;
/**
 * 将数据转换为sha256哈希
 * @param data 需要转换的数据
 * @returns string
 */
function toSha256(data) {
    let sha256 = crypto.createHash('sha256');
    return sha256.update(data).digest('hex');
}
exports.toSha256 = toSha256;
/**
 * 判断是否有特定字符并获取前面内容
 * @param data 需要处理的数据
 * @param char 特定字符
 * @param start 开始截取的位置
 * @returns string|number
 */
function getPartString(data, char, start = 0) {
    let end = data.indexOf(char);
    if (end !== -1) {
        return data.substring(start, end);
    }
    else {
        return end;
    }
}
exports.getPartString = getPartString;
/**
 * 判断系统类型
 * @returns 系统
 */
function detectOS() {
    let system = process.platform;
    if (system == 'darwin' || system === 'linux') {
        return 'linux';
    }
    else {
        return 'windows';
    }
}
exports.detectOS = detectOS;
/**
 * 设置对象可枚举
 * @param obj 对象
 * @returns 返回可枚举对象
 */
function setObjectPropertyEnumerable(obj) {
    Object.getOwnPropertyNames(obj).forEach((v) => {
        if (!obj.propertyIsEnumerable(v)) {
            Object.defineProperty(obj, v, {
                enumerable: true
            });
        }
    });
    return obj;
}
exports.setObjectPropertyEnumerable = setObjectPropertyEnumerable;
//# sourceMappingURL=base_util.js.map