"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.saveFile = exports.loadFile = exports.checkDir = exports.checkFile = exports.getFileFormat = exports.getSize = exports.getDirSize = exports.getFileSize = exports.isDir = exports.getFileStatus = exports.getAllFiles = exports.getPathName = exports.transUri2File = exports.isBinaryFile = exports.getWhiteList = exports.rmDirAsync = exports.unLinkAsync = exports.readDirAsync = exports.statAsync = exports.mkDirAsync = exports.fileExistAsync = exports.writeFileAsync = exports.readFileAsync = void 0;
const os = require("os");
const path = require("path");
const fs = require("fs");
const vscode_api_1 = require("../vscode_api");
const promisy_1 = require("./promisy");
const global_constants_1 = require("../consts/global_constants");
const base_util_1 = require("./base_util");
const vscode_api_2 = require("../vscode_api/vscode_api");
exports.readFileAsync = promisy_1.promisy(fs.readFile);
exports.writeFileAsync = promisy_1.promisy(fs.writeFile);
exports.fileExistAsync = promisy_1.promisy(fs.exists);
exports.mkDirAsync = promisy_1.promisy(fs.mkdir);
exports.statAsync = promisy_1.promisy(fs.stat);
exports.readDirAsync = promisy_1.promisy(fs.readdir);
exports.unLinkAsync = promisy_1.promisy(fs.unlink);
exports.rmDirAsync = promisy_1.promisy(fs.rmdir);
const _backendToolWhiteList = [
    /\.rpm$/
];
const _singleAppWhiteList = [
    /\.rpm$/,
    /\.tar$/,
    /\.gz$/,
    /\.zip$/,
    /\.gzip$/,
    /\.jar$/,
    /\.py$/,
    /\.pyc$/,
    /\.sh$/,
    isBinaryFile
];
const _binWhiteList = [
    isBinaryFile
];
const _confWhiteList = [
    /\.tar\.gz$/
];
const _hardWhiteList = [
    /\.tar\.gz$/
];
const whiteList = {
    backendTool: _backendToolWhiteList,
    singleApp: _singleAppWhiteList,
    bin: _binWhiteList,
    conf: _confWhiteList,
    hard: _hardWhiteList
};
/**
 * 获取对应的白名单
 * @param type 白名单类型
 * @returns 白名单
 */
function getWhiteList(type) {
    return whiteList[type];
}
exports.getWhiteList = getWhiteList;
/**
 * 判断是否二进制文件
 * @param filePath 文件路径
 * @returns boolean
 */
function isBinaryFile(filePath) {
    const content = fs.readFileSync(filePath);
    // elf文件的前4个字节是0x7F 0x45 0x4C 0x46 即 十进制的127 69 76 70
    const magicStr = content.slice(0, 4);
    return magicStr.join(',') === [127, 69, 76, 70].join(',');
}
exports.isBinaryFile = isBinaryFile;
/**
 * 把uri信息转化为文件信息
 * @param uri uri路径
 * @param isDir 是否文件夹
 * @returns 文件对象
 */
function transUri2File(uri, isDir) {
    return __awaiter(this, void 0, void 0, function* () {
        let uriPath;
        if (os.type() == 'Windows_NT') {
            // windows
            uriPath = uri.path.slice(1);
        }
        else if (os.type() == 'Darwin') {
            // mac
            uriPath = uri.path;
        }
        else if (os.type() == 'Linux') {
            // Linux
            uriPath = uri.path;
        }
        else {
            // 不支持提示
            uriPath = uri.path;
        }
        // const uriPath = uri.path.slice(1);
        const name = getPathName(uriPath);
        const path = uriPath;
        try {
            const sizeRes = yield getSize(uriPath, isDir);
            const size = sizeRes.size;
            const files = sizeRes.files;
            return {
                name,
                path,
                size,
                files
            };
        }
        catch (e) {
            throw e;
        }
    });
}
exports.transUri2File = transUri2File;
/**
 * 返回路径字符串中的最后文件名
 * @param filePath 文件路径
 * @returns 文件名
 */
function getPathName(pathStr) {
    return path.basename(pathStr);
}
exports.getPathName = getPathName;
/**
 * 异步获取路径下的文件总数
 * @param dirPath
 * @returns
 */
function getAllFiles(dirPath) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            let num = 0;
            const files = yield exports.readDirAsync(dirPath);
            for (const file of files) {
                const filePath = path.join(dirPath, file);
                const _isDir = yield isDir(filePath);
                if (_isDir) {
                    num = num + (yield getAllFiles(filePath));
                }
                else {
                    num = num + 1;
                }
            }
            return num;
        }
        catch (e) {
            throw e;
        }
    });
}
exports.getAllFiles = getAllFiles;
/**
 * 异步返回文件信息
 * @param pathStr 文件路径
 * @returns 文件信息stat
 */
function getFileStatus(pathStr) {
    return __awaiter(this, void 0, void 0, function* () {
        return exports.statAsync(pathStr);
    });
}
exports.getFileStatus = getFileStatus;
/**
 * 异步返回是否文件夹
 * @param pathStr 文件夹路径
 * @returns boolean
 */
function isDir(pathStr) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            const fileStatus = yield getFileStatus(pathStr);
            return fileStatus.isDirectory();
        }
        catch (e) {
            throw e;
        }
    });
}
exports.isDir = isDir;
/**
 * 异步返回指定文件的大小
 * @param filePath 文件路径
 * @returns size 文件大小
 */
function getFileSize(filePath) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            const fileStatus = yield getFileStatus(filePath);
            return Number(fileStatus.size);
        }
        catch (e) {
            throw e;
        }
    });
}
exports.getFileSize = getFileSize;
/**
 * 异步返回指定文件夹的大小
 * @param dirPath 文件夹路径
 * @returns size 文件夹大小
 */
function getDirSize(files, dirPath) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            let total = 0;
            for (const file of files) {
                const filePath = path.join(dirPath, file);
                const fileStatus = yield getFileStatus(filePath);
                if (fileStatus.isDirectory()) {
                    const files = yield exports.readDirAsync(filePath);
                    total = total + (yield getDirSize(files, filePath));
                }
                else {
                    total = total + (yield getFileSize(filePath));
                }
            }
            return total;
        }
        catch (e) {
            throw e;
        }
    });
}
exports.getDirSize = getDirSize;
/**
 * 异步返回指定文件或文件夹的大小
 * @param pathStr 资源路径
 * @param isDir 是否是文件夹
 * @returns size 资源大小
 */
function getSize(pathStr, isDir) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            if (!isDir) {
                return {
                    size: yield getFileSize(pathStr)
                };
            }
            else {
                const files = yield exports.readDirAsync(pathStr);
                let size = 0;
                size = yield getDirSize(files, pathStr);
                return {
                    size,
                    files
                };
            }
        }
        catch (e) {
            throw e;
        }
    });
}
exports.getSize = getSize;
/**
 * 返回格式化的文件信息
 * @param pathStr 本地路径
 * @returns 格式化对象
 */
function getFileFormat(pathStr) {
    try {
        const fileStr = fs.readFileSync(pathStr, 'utf-8');
        const fileName = getPathName(pathStr);
        const fileStat = fs.statSync(pathStr);
        return {
            content: fileStr,
            name: fileName,
            path: pathStr,
            stat: fileStat
        };
    }
    catch (error) {
        return {
            err: error
        };
    }
}
exports.getFileFormat = getFileFormat;
/**
 * 检验文件是否符合白名单
 * @param filePath 文件路径
 * @param whiteList 白名单
 * @returns boolean
 */
function checkFile(filePath, whiteList) {
    return base_util_1.inWhiteList(filePath, whiteList);
}
exports.checkFile = checkFile;
/**
 * 检验文件夹是否符合白名单
 * @param files 包含的文件
 * @param dirPath 文件夹路径
 * @param whiteList 白名单
 * @param canNest 是否可以嵌套
 * @returns Promise<boolean>
 */
function checkDir(files, dirPath, whiteList, canNest = true) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            let res = true;
            for (const file of files) {
                const filePath = path.join(dirPath, file);
                const _isDir = yield isDir(filePath);
                if (_isDir && !canNest) {
                    setTimeout(() => {
                        vscode_api_1.default.errMsg(vscode_api_2.I18n.common_file_error.cannot_inner_dir);
                    }, 1 * global_constants_1.SECOND);
                    throw new Error(vscode_api_2.I18n.common_file_error.cannot_inner_dir);
                }
                if (_isDir) {
                    const files = yield exports.readDirAsync(filePath);
                    res = res && (yield checkDir(files, filePath, whiteList));
                }
                else {
                    res = res && checkFile(filePath, whiteList);
                }
            }
            return res;
        }
        catch (e) {
            throw e;
        }
    });
}
exports.checkDir = checkDir;
/**
 * 获取文件内容
 * @param filePath 文件路径
 * @returns  文件内容
 */
function loadFile(filePath) {
    const absPath = path.join(vscode_api_1.default.extensionPath, filePath);
    let fileContent = '';
    let res = null;
    try {
        fileContent = fs.readFileSync(absPath, 'utf-8');
        res = fileContent;
    }
    catch (e) {
        // 文件不存在不需要中断程序，返回空值让调用此命令的程序处理
    }
    return res;
}
exports.loadFile = loadFile;
/**
 * 写入文件内容
 * @param filePath 文件路径
 * @param content 文件夹内容
 * @returns
 */
function saveFile(filePath, content) {
    const absPath = path.join(vscode_api_1.default.extensionPath, filePath);
    fs.writeFileSync(absPath, content, 'utf-8');
}
exports.saveFile = saveFile;
//# sourceMappingURL=file_util.js.map