"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.I18nService = void 0;
const vscode = require("vscode");
const zh_cn_1 = require("../i18n/zh-cn");
const en_us_1 = require("../i18n/en-us");
class I18nService {
    constructor() { }
    /** vscode判断界面语言类型的公共方法
     * 当界面语言为英文时，返回LANGUAGE_TYPE.EN
     * 当界面语言为非英文时，返回LANGUAGE_TYPE.ZH
     * 默认返回LANGUAGE_TYPE.ZH
     */
    static getLang() {
        const language = vscode.env.language;
        if (language) {
            return language.indexOf('en') !== -1 ? 1 /* EN */ : 0 /* ZH */;
        }
        else {
            return 0 /* ZH */;
        }
    }
    /** 获取i18n资源文件的公共方法
     * 当界面语言为英文时，返回英文资源文件
     * 当界面语言为非英文时，返回中文资源文件
     * 默认返回中文资源文件
     */
    static I18n() {
        // const i18n: any = vscode.env.language;
        const i18n = 'zh';
        let i18nContent = null;
        if (i18n) {
            i18nContent = i18n.indexOf('en') !== -1 ? en_us_1.I18N_EN : zh_cn_1.I18N_ZH;
        }
        else {
            i18nContent = zh_cn_1.I18N_ZH;
        }
        return i18nContent;
    }
    /** 替换i18n资源文件中{}的公共方法
     * @param i18nText 原始i18n资源文件内容
     * @param contentObj 将i18n资源文件中{}的内容替换为contentObj中的内容
     * @return 返回替换了{}之后的i18n资源文件
     */
    static I18nReplace(i18nText, contentObj) {
        i18nText = i18nText.split('.').reduce((pre, next) => {
            return pre[next];
        }, I18nService.I18n());
        const matchedArr = i18nText.match(/\{\}/g);
        let replaceStr = i18nText;
        if (matchedArr && matchedArr.length > 0) {
            const keys = Object.keys(contentObj);
            for (let i = 0; i < matchedArr.length; i++) {
                const value = contentObj[keys[i]];
                replaceStr = replaceStr.replace(/\{\}/, value);
            }
        }
        return replaceStr;
    }
}
exports.I18nService = I18nService;
//# sourceMappingURL=i18n_service.js.map