"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.checkResult = exports.createCheckFlag = exports.isCompleted = exports.overTime = exports.Polling = void 0;
const base_util_1 = require("./base_util");
/**
 * 轮询类 每个实例都可以进行一个轮询
 */
class Polling {
    constructor() {
        this._cancelCheck = false;
    }
    /**
     * 取消轮询
     * @returns this
     */
    cancelInterval() {
        clearInterval(this._intervalId);
        this._cancelCheck = true;
        return this;
    }
    /**
     * 轮询方法
     * @param options checkOptions, result, interval, timeout
     * @returns this
     */
    getResponseInterval(options) {
        this._cancelCheck = false;
        const { checkOptions, result, interval } = options;
        if (!checkOptions || !result || !interval)
            return this;
        const checkFunc = checkOptions.checkFunc;
        const stack = [];
        // 轮询超时控制：通过进行轮询的次数计算理想的轮询时间（实际轮询的时间应超过了理想轮询时间），与设置的超时时间比较
        let count = 0;
        // 使用定时器轮询
        this._intervalId = setInterval(() => __awaiter(this, void 0, void 0, function* () {
            // 超时检测
            count += 1;
            if (overTime(count * options.interval, options.timeout)) {
                clearInterval(this._intervalId);
                base_util_1.callHooks('timeout', result);
                return;
            }
            // 等待前面的轮询结束
            if (stack.length) {
                try {
                    yield stack[stack.length - 1];
                }
                catch (e) {
                    throw e;
                }
            }
            // 结果判定
            isCompleted({
                checkFunc: (isCancel) => __awaiter(this, void 0, void 0, function* () {
                    if (isCancel)
                        return;
                    stack.push(checkFunc());
                    try {
                        const res = yield stack[stack.length - 1];
                        stack.shift();
                        return res;
                    }
                    catch (e) {
                        throw e;
                    }
                }),
                cancelCheck: this._cancelCheck,
                success: options.checkOptions.success,
                fail: options.checkOptions.fail
            })
                .then((res) => {
                base_util_1.callHooks('success', result, res);
            })
                .catch((reason) => {
                base_util_1.callHooks('fail', result, reason);
            })
                .finally(() => {
                clearInterval(this._intervalId);
            });
        }), options.interval);
        return this;
    }
}
exports.Polling = Polling;
/**
 * 判断当前时间是否超过了设定时间
 * @param realTime 当前时间
 * @param setTime 设定时间
 * @returns boolean
 */
function overTime(realTime, setTime) {
    return setTime && (realTime > setTime);
}
exports.overTime = overTime;
/**
 * 处理一个异步操作结果的方法
 * @param options 包含checkFunc，success，fail属性的对象
 * @returns Promise 在通过了success方法后resolve，在通过fail方法后reject,success优先级高
 */
function isCompleted(options) {
    const { success, fail, cancelCheck, checkFunc } = options;
    if (!checkFunc) {
        throw new Error('参数中需要包含属性checkFunc');
    }
    return new Promise((resolve, reject) => __awaiter(this, void 0, void 0, function* () {
        try {
            let res = yield checkFunc(cancelCheck);
            (res instanceof Buffer) && (res = base_util_1.buf2String(res));
            if (cancelCheck) {
                resolve(2 /* CANCEL */);
            }
            else if (success && success(res)) {
                resolve(res);
            }
            else if (fail && fail(res)) {
                reject(res);
            }
            else {
                // 什么也不做
            }
        }
        catch (e) {
            throw e;
        }
    }));
}
exports.isCompleted = isCompleted;
function createCheckFlag(options) {
    const res = {
        success: null
    };
    if (options.success instanceof Function) {
        res.success = options.success;
    }
    else if (options.success instanceof RegExp) {
        res.success = (str) => {
            return new RegExp(options.success).test(str);
        };
    }
    if (!options.failure) {
        options.failure = /(Abnormal exit)|(ERROR)|(error)/;
    }
    if (options.failure instanceof Function) {
        res.failure = options.failure;
    }
    else if (options.failure instanceof RegExp) {
        res.failure = (str) => {
            return new RegExp(options.failure).test(str);
        };
    }
    return res;
}
exports.createCheckFlag = createCheckFlag;
// 分析评估结果
function checkResult(data) {
    let resultArray = data.replace(/\s*/g, '').split(',');
    let result = true;
    resultArray.some(item => {
        if (item == '0success') {
            result = false;
        }
    });
    return result;
}
exports.checkResult = checkResult;
//# sourceMappingURL=polling_util.js.map